import { graphStateEnum } from "./graphStateEnum";
import { sysGraphHttpUtils } from "@/utils/http/sysGraphHttpUtils";
import { logicConfig } from "@/logicConfig";
import moment from 'moment';

export class sysGraphController {
    private static sysGraphHttpUtilsInstance = new sysGraphHttpUtils();
    //key为系统类型编码，值为 系统图类型 > 模板数据 的二级结构数组
    private static _tempTemplateObj = {};
    //三级数组 专业>系统类型>系统实例
    private static zhuanyeArr = [];


    //根据状态编码转状态名称
    static getStateNameByCode(stateCode: string) {
        return stateCode == graphStateEnum.Draft ? '草稿' :
            stateCode == graphStateEnum.Publish ? '上架' :
                stateCode == graphStateEnum.Recyle ? '回收站' : '';
    }

    /**
     * 查询系统图列表
     * @param grpphName 系统图名称
     */
    static async getDiagrams(grpphName: string) {
        //先取得所有的系统图，注：没有分页
        var resultObj = await this.sysGraphHttpUtilsInstance.postRequest('/diagram/getDiagrams', { name: grpphName });
        if (resultObj.result != logicConfig.resultObj.success)
            console.error(resultObj.reason);

        //key为系统类型编码，值为系统类型数据
        var _tempSystemTypeObj = {};
        var newDataArr = [];
        var dataArr = (resultObj.data || []).filter(_c => {
            return (_c.extraProps || {}).state != graphStateEnum.Recyle;
        });
        dataArr.sort(function (a, b) {
            return b.createTime - a.createTime;
        });


        //取得专业>系统类型>系统实例  以和系统图列表中的系统类型编码 对应以获取系统类型名称
        if (this.zhuanyeArr.length == 0) {
            var url2 = '/diagram/major/system/instance';
            var zhuanyeObj = await this.sysGraphHttpUtilsInstance.postRequest(url2, {});
            this.zhuanyeArr = zhuanyeObj.data || [];
        }


        for (let i = 0; i < dataArr.length; i++) {
            let _c = dataArr[i];
            let extraProps = _c.extraProps;
            //图状态（Draft: 未发布, WaitCheck: 待审核, Checked: 审核完成, Recyle: 回收站, Publish: 发布）
            let stateName = this.getStateNameByCode(extraProps.state);

            //获取系统类型名称
            let systemTypeName = (_tempSystemTypeObj[_c.system] || {}).aliasName;
            if (!systemTypeName) {
                getSystemTypeByCode(_c.system);
                systemTypeName = (_tempSystemTypeObj[_c.system] || {}).aliasName || '';
            }

            //获取模版名称
            let _templateObj = await this.getTemplateGraphTypeBySysTypeCode(_c.system, _c.templateId);
            let templateName = ((_templateObj || {}).template || {}).name || '';

            //格式化日期时间
            let momentInstance = moment(_c.createTime);
            let timeStr = momentInstance.format('YYYY[/]MM[/]DD[ ]HH[:]mm');

            newDataArr.push({
                id: _c.id,
                name: _c.name,
                //系统类型名称
                sysType: systemTypeName,
                //系统实例名称
                sysInstance: extraProps.systemInstanceName,
                //模板名称
                sysTemplate: templateName,
                stateName: stateName,
                createTime: timeStr
            });
        }
        return newDataArr;


        function getSystemTypeByCode(systemTypeCode: string) {
            for (let i = 0; i < sysGraphController.zhuanyeArr.length; i++) {
                //专业
                let zhuanye = sysGraphController.zhuanyeArr[i];
                //系统类型数组
                let systemTypeArr = zhuanye.children || [];
                let isFind = false;
                for (let j = 0; j < systemTypeArr.length; j++) {
                    //系统类型
                    let systemType = systemTypeArr[j];
                    if (systemType.code == systemTypeCode) {
                        isFind = true;
                        _tempSystemTypeObj[systemTypeCode] = systemType;
                        break;
                    }
                }
                if (isFind)
                    break;
            }
        };
    }

    /**
     * 根据系统类型查询系统图模板和系统图类型，数据结构：系统图类型 ->  系统图模版
     * @param sysTypeCode 系统类型编码
     * @param templateId 模版ID
     * @return {template:{id:'',name:''},graphType:{id:'',name:''}}
     */
    static async getTemplateGraphTypeBySysTypeCode(sysTypeCode: string, templateId: string) {
        var dataArr = this._tempTemplateObj[sysTypeCode];

        if (!dataArr) {
            let url = '/diagram/systemType/template';
            let resultObj = await sysGraphController.sysGraphHttpUtilsInstance.postRequest(url, { system: sysTypeCode });
            dataArr = resultObj.data || [];
        }
        this._tempTemplateObj[sysTypeCode] = dataArr;

        for (let i = 0; i < dataArr.length; i++) {
            //_sysGraphType为系统图类型
            let sysGraphType = dataArr[i];
            //模板数组
            let templateArr = sysGraphType.children || [];
            for (let j = 0; j < templateArr.length; j++) {
                //模板
                let template = templateArr[j];
                if (template.id == templateId) {
                    return {
                        template: { id: template.id, name: template.name },
                        graphType: { id: sysGraphType.id, name: sysGraphType.name }
                    };
                }
            }
        }
        return null;
    }


    /**
     * 根据项目查询该项目下的专业>系统类型>系统实例
     * @param projectId 项目ID
     * @param groupCode 集团编码
     */
    static async getSysInstanceByProject(projectId: string, groupCode: string) {
        var url = '/diagram/major/system/instance?projectId=' + projectId + '&groupCode=' + groupCode;
        var resultObj = await this.sysGraphHttpUtilsInstance.postRequest(url, {});
        if (resultObj.result != logicConfig.resultObj.success)
            console.error(resultObj.reason);
        var dataArr = resultObj.data || [];
        this.zhuanyeArr = dataArr;
        var newDataArr = [];

        dataArr.forEach(_c => {
            //_c为专业
            let zhuanye = { value: _c.id, label: _c.label, code: _c.code, children: [] };
            let sysTypeArr = [];
            (_c.children || []).forEach(_c2 => {
                //_c2为系统类型
                let sysType = { value: _c2.id, label: _c2.aliasName, code: _c2.code, children: [] };
                let sysInstanceArr = [];
                (_c2.children || []).forEach(_c3 => {
                    //_c3为系统实例
                    sysInstanceArr.push({ value: _c3.id, label: _c3.name, code: _c3.code });
                });
                sysType.children = sysInstanceArr;
                sysTypeArr.push(sysType);
            });
            zhuanye.children = sysTypeArr;
            newDataArr.push(zhuanye);
        });
        return newDataArr;
    }

    /**
     * 根据系统类型查询系统图模板，数据结构：系统图类型 ->  系统图模版
     * @param sysTypeCode 系统类型编码
     */
    static async getTemplateBySysTypeCode(sysTypeCode: string) {
        var url = '/diagram/systemType/template';
        var resultObj = await this.sysGraphHttpUtilsInstance.postRequest(url, { system: sysTypeCode });
        if (resultObj.result != logicConfig.resultObj.success)
            console.error(resultObj.reason);
        var dataArr = resultObj.data || [];
        var newDataArr = [];

        dataArr.forEach(_sysGraphType => {
            //_sysGraphType为系统图类型
            let sysGraphType = { value: _sysGraphType.id, label: _sysGraphType.name, code: _sysGraphType.code, children: [] };
            let templateArr = [];
            (_sysGraphType.children || []).forEach(_template => {
                //_template为模版
                let template = { value: _template.id, label: _template.name, code: _template.code };
                templateArr.push(template);
            });
            sysGraphType.children = templateArr;
            newDataArr.push(sysGraphType);
        });
        return newDataArr;
    }

    /**
     * 新增系统图
     * @param _paramObj {name:'系统图名称',type:'系统图类型编码',templateId:'引用的模板id',system:'所属的系统类型编码',projectId:'项目id',systemId:'对应的系统实例id',groupCode:'集团编码',}
     */
    static async createSysGraph(_paramObj: any) {
        var url = '/diagram/newDiagram';
        var resultObj = await this.sysGraphHttpUtilsInstance.postRequest(url, _paramObj);
        if (resultObj.result != logicConfig.resultObj.success) {
            resultObj.reason = '新建系统图失败：' + resultObj.reason;
            return resultObj;
        }

        var dataObj = resultObj.data || {};
        if (!dataObj.id)
            return { result: logicConfig.resultObj.failure, reason: '缺少系统图ID' };

        //新增成功后，要加载数据
        var loadDataUrl = '/diagram/loadData';
        var loadResultObj = await this.sysGraphHttpUtilsInstance.postRequest(loadDataUrl, { id: dataObj.id });
        if (loadResultObj.result != logicConfig.resultObj.success) {
            loadResultObj.reason = '加载模板数据失败：' + loadResultObj.reason;
            return loadResultObj;
        }

        //加载数据成功后保存数据
        var saveResultObj = await this.saveSysGraph(loadResultObj.data);
        if (saveResultObj.result != logicConfig.resultObj.success) {
            saveResultObj.reason = '保存系统图数据失败：' + saveResultObj.reason;
            return saveResultObj;
        }

        //因为保存数据成功返回的data里的数据不全，所以返回加载数据成功后的数据给页面
        return loadResultObj;
    }

    /**
     * 保存系统图数据
     * @param _paramObj 参见后台loadData接口的返回
     */
    static async saveSysGraph(_paramObj: any) {
        var saveUrl = '/diagram/newDiagram';
        var saveResultObj = await this.sysGraphHttpUtilsInstance.postRequest(saveUrl, _paramObj);
        return saveResultObj;
    }

    /**
     * 根据系统图ID查询系统图信息
     * @param id 系统图ID
     */
    static async getDiagramById(id: string, groupCode: string, projectId: string) {
        var url = '/diagram/getDiagram?diagramId=' + id;
        var resultObj = await this.sysGraphHttpUtilsInstance.getRequest(url, {});
        if (resultObj.result != logicConfig.resultObj.success) {
            console.error(resultObj.reason);
            return resultObj;
        }

        var dataObj = resultObj.data || {};
        if (!dataObj.id)
            return { result: logicConfig.resultObj.failure, reason: '缺少系统图ID' };

        //取得专业>系统类型>系统实例  以和系统图列表中的系统类型编码 对应以获取系统实例名称
        if (this.zhuanyeArr.length == 0) {
            var url2 = '/diagram/major/system/instance?groupCode=' + groupCode + '&projectId=' + projectId;
            var zhuanyeObj = await this.sysGraphHttpUtilsInstance.postRequest(url2, {});
            this.zhuanyeArr = zhuanyeObj.data || [];
        }

        //获取系统实例名称
        var _systemInstance = getSystemInstanceByCode(resultObj.data.systemId);
        resultObj.data.systemInstanceName = _systemInstance.name || '';


        //获取系统图类型和系统图模版
        var _temoObj = await this.getTemplateGraphTypeBySysTypeCode(resultObj.data.system, resultObj.data.templateId);
        resultObj.data.graphTypeName = ((_temoObj || {}).graphType || {}).name;
        resultObj.data.templateName = ((_temoObj || {}).template || {}).name;

        //状态名称
        resultObj.data.stateName = this.getStateNameByCode(resultObj.data.extraProps.state);


        return resultObj;

        //获取系统实例信息
        function getSystemInstanceByCode(systemInstanceId: string) {
            for (let i = 0; i < sysGraphController.zhuanyeArr.length; i++) {
                //专业
                let zhuanye = sysGraphController.zhuanyeArr[i];
                //系统类型数组
                let systemTypeArr = zhuanye.children || [];
                let isFind = false;
                for (let j = 0; j < systemTypeArr.length; j++) {
                    //系统类型
                    let systemType = systemTypeArr[j];
                    //系统实例数组
                    let systemInstanceArr = systemType.children || [];
                    for (let k = 0; k < systemInstanceArr.length; k++) {
                        //系统实例
                        let systemInstance = systemInstanceArr[k];
                        if (systemInstance.id == systemInstanceId)
                            return systemInstance;
                    }
                }
                if (isFind)
                    break;
            }
        };

        return {
            result: 'success',
            data: {
                "id": "5715eb4e955249babeba81641f868328",
                "name": "高压系统图7",
                "remark": null,
                "type": "SETDHVSL",
                "templateId": "cef7e4266e22489dbd78e3d8b0248292",
                "system": "SETD",
                "projectId": "Pj1101050031",
                "systemId": "Sy11010500316d809bec3e06439e91cc0852a4853dcc",
                "groupCode": "BR",
                "extraProps": {
                    "state": "Draft"
                },
                "nodes": [
                    {
                        "id": "665bcb59f4354d00ab2db5528f7a0cd9",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 20,
                            "y": 20
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "AH5",
                        "layoutIndex": 0,
                        "dataObject": {
                            "id": "Eq1101050031ef68077a421c42ae9ed64d4509bc8d2f",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压馈线柜-XQ9GR",
                            "localId": "1H4",
                            "localName": "至1#高压冷机高压开关柜（1H4）",
                            "objType": "equipment",
                            "classCode": "SETDHF",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635131901077.png",
                                    "name": "1635131901077",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635660",
                            "cADID": "1H4",
                            "ratedI": 100,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "147419.49,14675.0,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq1101050031ef68077a421c42ae9ed64d4509bc8d2f",
                        "objClassCode": "SETDHF",
                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "至1#高压冷机高压开关柜（1H4）",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "de1b2fc7c9bb46ea820f48c01b01bdde",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 20,
                            "y": 20
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "AH4",
                        "layoutIndex": 0,
                        "dataObject": {
                            "id": "Eq110105003101228dce0fff4268aea05f1fe968eb63",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "modifiedTime": 1639034991000,
                            "modifier": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压馈线柜-30VAS",
                            "localId": "2H16",
                            "localName": "至GTR2变压器高压开关柜（2H16）",
                            "objType": "equipment",
                            "classCode": "SETDHF",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635132039836.png",
                                    "name": "1635132039836",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635795",
                            "cADID": "2H16",
                            "ratedI": 200,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "158039.49,10225.0,-8450.0",
                            "manufacturer": "大厂",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq110105003101228dce0fff4268aea05f1fe968eb63",
                        "objClassCode": "SETDHF",
                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "至GTR2变压器高压开关柜（2H16）",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "104aebb297eb4fc4ad56b8401f5c62ce",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 140,
                            "y": 20
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "AH4",
                        "layoutIndex": 1,
                        "dataObject": {
                            "id": "Eq1101050031026a23aa76584336bcf695b6680f4702",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压馈线柜-MZJKK",
                            "localId": "2H8",
                            "localName": "至DTR1变压器高压开关柜（2H8）",
                            "objType": "equipment",
                            "classCode": "SETDHF",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635132033445.png",
                                    "name": "1635132033445",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635769",
                            "cADID": "2H8",
                            "ratedI": 100,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "161019.49,14675.0,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq1101050031026a23aa76584336bcf695b6680f4702",
                        "objClassCode": "SETDHF",
                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "至DTR1变压器高压开关柜（2H8）",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "9899f9764dee43cd90b979145866f9b7",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 260,
                            "y": 20
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "AH4",
                        "layoutIndex": 2,
                        "dataObject": {
                            "id": "Eq1101050031062159cf022846e087d17615389a0e7e",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压馈线柜-L0Q0Y",
                            "localId": "1H17",
                            "localName": "至JTR2变压器高压开关柜（1H17）",
                            "objType": "equipment",
                            "classCode": "SETDHF",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635132028195.png",
                                    "name": "1635132028195",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635806",
                            "cADID": "1H17",
                            "ratedI": 100,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "148739.32,10225.0,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq1101050031062159cf022846e087d17615389a0e7e",
                        "objClassCode": "SETDHF",
                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "至JTR2变压器高压开关柜（1H17）",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "0079b127e99c443fbde993b93a18bf58",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 380,
                            "y": 20
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "AH4",
                        "layoutIndex": 3,
                        "dataObject": {
                            "id": "Eq11010500310ef16b1a962e47f099286adf2bb266d5",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压馈线柜-SX4KP",
                            "localId": "1H9",
                            "localName": "至4#高压冷机高压开关柜（1H19）",
                            "objType": "equipment",
                            "classCode": "SETDHF",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635132021639.png",
                                    "name": "1635132021639",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635726",
                            "cADID": "1H9",
                            "ratedI": 100,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "151419.49,14675.0,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq11010500310ef16b1a962e47f099286adf2bb266d5",
                        "objClassCode": "SETDHF",
                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "至4#高压冷机高压开关柜（1H19）",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "0c8d855d39de490a9270e8e269a7e245",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 500,
                            "y": 20
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "AH4",
                        "layoutIndex": 4,
                        "dataObject": {
                            "id": "Eq110105003128ca598367094aa191f0247062ae1cd4",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压馈线柜-Q3GG6",
                            "localId": "2H4",
                            "localName": "至ITR1变压器高压开关柜（2H4）",
                            "objType": "equipment",
                            "classCode": "SETDHF",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635132016310.png",
                                    "name": "1635132016310",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635732",
                            "cADID": "2H4",
                            "ratedI": 100,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "157819.49,14675.0,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq110105003128ca598367094aa191f0247062ae1cd4",
                        "objClassCode": "SETDHF",
                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "至ITR1变压器高压开关柜（2H4）",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "ddad82b74c544c82afc7ec34630a5699",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 620,
                            "y": 20
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "AH4",
                        "layoutIndex": 5,
                        "dataObject": {
                            "id": "Eq110105003128e188326d0c491192e50e1dfa8f9e88",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压馈线柜-657H4",
                            "localId": "2H14",
                            "localName": "至DTR2变压器高压开关柜（2H14）",
                            "objType": "equipment",
                            "classCode": "SETDHF",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635132011691.png",
                                    "name": "1635132011691",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635793",
                            "cADID": "2H14",
                            "ratedI": 100,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "159639.49,10225.0,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq110105003128e188326d0c491192e50e1dfa8f9e88",
                        "objClassCode": "SETDHF",
                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "至DTR2变压器高压开关柜（2H14）",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "40227bad01004fcf8b27fc9fbb5f3b6d",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 740,
                            "y": 20
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "AH4",
                        "layoutIndex": 6,
                        "dataObject": {
                            "id": "Eq1101050031313199daf1da4c0d875be48ce7abc27e",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压馈线柜-MFPK3",
                            "localId": "1H16",
                            "localName": "至CTR2变压器高压开关柜（1H16）",
                            "objType": "equipment",
                            "classCode": "SETDHF",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635132002308.png",
                                    "name": "1635132002308",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635805",
                            "cADID": "1H16",
                            "ratedI": 100,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "149539.32,10225.0,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq1101050031313199daf1da4c0d875be48ce7abc27e",
                        "objClassCode": "SETDHF",
                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "至CTR2变压器高压开关柜（1H16）",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "fb62d9a766d74a418c1cc5379183357c",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 860,
                            "y": 20
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "AH4",
                        "layoutIndex": 7,
                        "dataObject": {
                            "id": "Eq11010500313487b5c481b94b448beff55119dfa83f",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压馈线柜-VPJ9E",
                            "localId": "1H8",
                            "localName": "至JTR1变压器高压开关柜（1H8）",
                            "objType": "equipment",
                            "classCode": "SETDHF",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635132006695.png",
                                    "name": "1635132006695",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635709",
                            "cADID": "1H8",
                            "ratedI": 100,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "150619.49,14675.0,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq11010500313487b5c481b94b448beff55119dfa83f",
                        "objClassCode": "SETDHF",
                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "至JTR1变压器高压开关柜（1H8）",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "de98991bc9564e078c5d675698e77f28",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 980,
                            "y": 20
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "AH4",
                        "layoutIndex": 8,
                        "dataObject": {
                            "id": "Eq110105003136ea4dfb412d43ce8b7300ef5ce15ff7",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压馈线柜-U8KAC",
                            "localId": "1H20",
                            "localName": "至6#高压冷机高压开关柜（1H20）",
                            "objType": "equipment",
                            "classCode": "SETDHF",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635131997646.png",
                                    "name": "1635131997646",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635833",
                            "cADID": "1H20",
                            "ratedI": 100,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "146339.32,10225.0,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq110105003136ea4dfb412d43ce8b7300ef5ce15ff7",
                        "objClassCode": "SETDHF",
                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "至6#高压冷机高压开关柜（1H20）",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "ee50bc4e37734870afbc4d8b947b50a1",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 1100,
                            "y": 20
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "AH4",
                        "layoutIndex": 9,
                        "dataObject": {
                            "id": "Eq110105003143051732a5ee463fa85ab9eaeeba77ff",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压馈线柜-LT3R8",
                            "localId": "1H19",
                            "localName": "至4#高压冷机高压开关柜（1H19）",
                            "objType": "equipment",
                            "classCode": "SETDHF",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635131992585.png",
                                    "name": "1635131992585",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635808",
                            "cADID": "1H19",
                            "ratedI": 100,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "147139.32,10225.0,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq110105003143051732a5ee463fa85ab9eaeeba77ff",
                        "objClassCode": "SETDHF",
                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "至4#高压冷机高压开关柜（1H19）",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "fa9475c542b4412fb5a2c674fde0b0d7",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 1220,
                            "y": 20
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "AH4",
                        "layoutIndex": 10,
                        "dataObject": {
                            "id": "Eq1101050031501fcc3a7b52427f8cee02fcfefca03d",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压馈线柜-7XM1E",
                            "localId": "2H13",
                            "localName": "至GTR1变压器高压开关柜（2H5）",
                            "objType": "equipment",
                            "classCode": "SETDHF",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635131988003.png",
                                    "name": "1635131988003",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635790",
                            "cADID": "2H13",
                            "ratedI": 100,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "160439.49,10225.0,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq1101050031501fcc3a7b52427f8cee02fcfefca03d",
                        "objClassCode": "SETDHF",
                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "至GTR1变压器高压开关柜（2H5）",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "46a481f457b643cfb22efa581834e180",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 1340,
                            "y": 20
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "AH4",
                        "layoutIndex": 11,
                        "dataObject": {
                            "id": "Eq110105003154c5e7447ad1427687cf0142c84fbab4",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压馈线柜-0H72G",
                            "localId": "1H5",
                            "localName": "至3#高压冷机高压开关柜（1H5）",
                            "objType": "equipment",
                            "classCode": "SETDHF",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635131983256.png",
                                    "name": "1635131983256",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635706",
                            "cADID": "1H5",
                            "ratedI": 100,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "148219.49,14675.0,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq110105003154c5e7447ad1427687cf0142c84fbab4",
                        "objClassCode": "SETDHF",
                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "至3#高压冷机高压开关柜（1H5）",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "332e94ae0ae147f88d1b449f9ad85c6d",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 1460,
                            "y": 20
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "AH4",
                        "layoutIndex": 12,
                        "dataObject": {
                            "id": "Eq110105003156026840464d42aebb769c16ffb7f5fb",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压馈线柜-EWUJ4",
                            "localId": "1H15",
                            "localName": "至BTR2变压器高压开关柜（1H15）",
                            "objType": "equipment",
                            "classCode": "SETDHF",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635131978046.png",
                                    "name": "1635131978046",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635804",
                            "cADID": "1H15",
                            "ratedI": 100,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "150339.32,10225.0,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq110105003156026840464d42aebb769c16ffb7f5fb",
                        "objClassCode": "SETDHF",
                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "至BTR2变压器高压开关柜（1H15）",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "c2e6557968104d47b7209c719086fd9b",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 1580,
                            "y": 20
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "AH4",
                        "layoutIndex": 13,
                        "dataObject": {
                            "id": "Eq110105003171d36433975f4c60a660451cc5b2a15a",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压馈线柜-PBMHK",
                            "localId": "1H10",
                            "localName": "至ATR1变压器高压开关柜（1H10）",
                            "objType": "equipment",
                            "classCode": "SETDHF",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635131973401.png",
                                    "name": "1635131973401",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635802",
                            "cADID": "1H10",
                            "ratedI": 100,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "152219.49,14675.0,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq110105003171d36433975f4c60a660451cc5b2a15a",
                        "objClassCode": "SETDHF",
                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "至ATR1变压器高压开关柜（1H10）",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "7b96f2eab16d4affb441108b68afc891",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 1700,
                            "y": 20
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "AH4",
                        "layoutIndex": 14,
                        "dataObject": {
                            "id": "Eq1101050031724af298a2b8421e864583aab9db71de",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压馈线柜-1ECNN",
                            "localId": "2H6",
                            "localName": "至HTR1变压器高压开关柜（2H6）",
                            "objType": "equipment",
                            "classCode": "SETDHF",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635131968575.png",
                                    "name": "1635131968575",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635760",
                            "cADID": "2H6",
                            "ratedI": 100,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "159419.49,14675.0,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq1101050031724af298a2b8421e864583aab9db71de",
                        "objClassCode": "SETDHF",
                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "至HTR1变压器高压开关柜（2H6）",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "4a75d62a98d1439c8b3d4ed55e610994",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 1820,
                            "y": 20
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "AH4",
                        "layoutIndex": 15,
                        "dataObject": {
                            "id": "Eq1101050031900b335312c5457bba6315e0a6a983fa",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压馈线柜-YU4GS",
                            "localId": "1H21",
                            "localName": "至8#高压冷机高压开关柜（1H21）",
                            "objType": "equipment",
                            "classCode": "SETDHF",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635131963280.png",
                                    "name": "1635131963280",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635841",
                            "cADID": "1H21",
                            "ratedI": 100,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "145564.32,10225.0,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq1101050031900b335312c5457bba6315e0a6a983fa",
                        "objClassCode": "SETDHF",
                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "至8#高压冷机高压开关柜（1H21）",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "13d58337bc9b425283fa2433450ecf5f",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 1940,
                            "y": 20
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "AH4",
                        "layoutIndex": 16,
                        "dataObject": {
                            "id": "Eq11010500319b69d94e1d9c40e184a160453ccf0a24",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压馈线柜-3MHLZ",
                            "localId": "1H7",
                            "localName": "至7#高压冷机高压开关柜（1H7）",
                            "objType": "equipment",
                            "classCode": "SETDHF",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635131958483.png",
                                    "name": "1635131958483",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635708",
                            "cADID": "1H7",
                            "ratedI": 100,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "149819.49,14675.0,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq11010500319b69d94e1d9c40e184a160453ccf0a24",
                        "objClassCode": "SETDHF",
                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "至7#高压冷机高压开关柜（1H7）",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "37fcd93aeef74eb3a940148769b9b692",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 2060,
                            "y": 20
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "AH4",
                        "layoutIndex": 17,
                        "dataObject": {
                            "id": "Eq11010500319e5df7eb4ba9461ea4330cb8224041de",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压馈线柜-0JRDF",
                            "localId": "2H17",
                            "localName": "至ITR2变压器高压开关柜（2H17）",
                            "objType": "equipment",
                            "classCode": "SETDHF",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635131953786.png",
                                    "name": "1635131953786",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635796",
                            "cADID": "2H17",
                            "ratedI": 150,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "157239.49,10225.0,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq11010500319e5df7eb4ba9461ea4330cb8224041de",
                        "objClassCode": "SETDHF",
                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "至ITR2变压器高压开关柜（2H17）",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "018c985f4d094e2187fc56a276b3c567",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 2180,
                            "y": 20
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "AH4",
                        "layoutIndex": 18,
                        "dataObject": {
                            "id": "Eq1101050031a154b8ea354549a3b62eef40f03f2e15",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压馈线柜-B6NJT",
                            "localId": "2H7",
                            "localName": "至FTR1变压器高压开关柜（2H7）",
                            "objType": "equipment",
                            "classCode": "SETDHF",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635131948987.png",
                                    "name": "1635131948987",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635761",
                            "cADID": "2H7",
                            "ratedI": 100,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "160219.49,14675.0,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq1101050031a154b8ea354549a3b62eef40f03f2e15",
                        "objClassCode": "SETDHF",
                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "至FTR1变压器高压开关柜（2H7）",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "23106fade3d14576844a1a1eac87123d",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 2300,
                            "y": 20
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "AH4",
                        "layoutIndex": 19,
                        "dataObject": {
                            "id": "Eq1101050031a366b97e21924b97bc501aed18b295af",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压馈线柜-MASE7",
                            "localId": "2H15",
                            "localName": "至HTR2变压器高压开关柜（2H15）",
                            "objType": "equipment",
                            "classCode": "SETDHF",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635131943907.png",
                                    "name": "1635131943907",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635794",
                            "cADID": "2H15",
                            "ratedI": 100,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "158839.49,10225.0,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq1101050031a366b97e21924b97bc501aed18b295af",
                        "objClassCode": "SETDHF",
                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "至HTR2变压器高压开关柜（2H15）",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "1b08de72c361438688a4cd2c5f44a3d5",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 2420,
                            "y": 20
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "AH4",
                        "layoutIndex": 20,
                        "dataObject": {
                            "id": "Eq1101050031a9d4e7d6244e491d91ddc8f3bb52c9f8",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压馈线柜-5G0HB",
                            "localId": "1H11",
                            "localName": "至BTR1变压器高压开关柜（1H11）",
                            "objType": "equipment",
                            "classCode": "SETDHF",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635131939263.png",
                                    "name": "1635131939263",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635801",
                            "cADID": "1H11",
                            "ratedI": 100,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "153019.49,14675.0,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq1101050031a9d4e7d6244e491d91ddc8f3bb52c9f8",
                        "objClassCode": "SETDHF",
                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "至BTR1变压器高压开关柜（1H11）",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "793cbf708aee499f8d036ea5cb3e8e52",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 2540,
                            "y": 20
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "AH4",
                        "layoutIndex": 21,
                        "dataObject": {
                            "id": "Eq1101050031aa5495ba596e4611a6b48e9eb67c5f46",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压馈线柜-F8TMX",
                            "localId": "1H18",
                            "localName": "至2#高压冷机高压开关柜（1H18）",
                            "objType": "equipment",
                            "classCode": "SETDHF",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635131934621.png",
                                    "name": "1635131934621",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635807",
                            "cADID": "1H18",
                            "ratedI": 100,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "147939.32,10225.0,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq1101050031aa5495ba596e4611a6b48e9eb67c5f46",
                        "objClassCode": "SETDHF",
                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "至2#高压冷机高压开关柜（1H18）",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "e1515037460049d892156fb66d83548a",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 2660,
                            "y": 20
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "AH4",
                        "layoutIndex": 22,
                        "dataObject": {
                            "id": "Eq1101050031abb2871e19a74143ae43bcb68fab1c63",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压馈线柜-B9DG6",
                            "localId": "1H14",
                            "localName": "至ATR1变压器高压开关柜（1H14）",
                            "objType": "equipment",
                            "classCode": "SETDHF",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635131929119.png",
                                    "name": "1635131929119",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635803",
                            "cADID": "1H14",
                            "ratedI": 100,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "151139.32,10225.0,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq1101050031abb2871e19a74143ae43bcb68fab1c63",
                        "objClassCode": "SETDHF",
                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "至ATR1变压器高压开关柜（1H14）",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "23c6d3b608a840ecad4e0a741a4d0021",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 2780,
                            "y": 20
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "AH4",
                        "layoutIndex": 23,
                        "dataObject": {
                            "id": "Eq1101050031c8665c4ca53d4b36b6d87b1542e7a732",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压馈线柜-NP9T5",
                            "localId": "1H6",
                            "localName": "至5#高压冷机高压开关柜（1H6）",
                            "objType": "equipment",
                            "classCode": "SETDHF",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635131923416.png",
                                    "name": "1635131923416",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635707",
                            "cADID": "1H6",
                            "ratedI": 100,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "149019.49,14675.0,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq1101050031c8665c4ca53d4b36b6d87b1542e7a732",
                        "objClassCode": "SETDHF",
                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "至5#高压冷机高压开关柜（1H6）",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "79e0a727d71f4691b9584a32499c0af0",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 2900,
                            "y": 20
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "AH4",
                        "layoutIndex": 24,
                        "dataObject": {
                            "id": "Eq1101050031de22c8e4b6c94c998b23ec8ffbf5cbf9",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压馈线柜-VJKJP",
                            "localId": "2H9",
                            "localName": "至ETR1变压器高压开关柜（2H9）",
                            "objType": "equipment",
                            "classCode": "SETDHF",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635131918643.png",
                                    "name": "1635131918643",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635770",
                            "cADID": "2H9",
                            "ratedI": 150,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "161819.49,14675.0,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq1101050031de22c8e4b6c94c998b23ec8ffbf5cbf9",
                        "objClassCode": "SETDHF",
                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "至ETR1变压器高压开关柜（2H9）",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "bd5b097b4bb8402a976c18e536c2de28",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 3020,
                            "y": 20
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "AH4",
                        "layoutIndex": 25,
                        "dataObject": {
                            "id": "Eq1101050031df33c8d6f3a147cba2768f6e292be874",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压馈线柜-TVQF3",
                            "localId": "2H12",
                            "localName": "至ETR2变压器高压开关柜（2H12）",
                            "objType": "equipment",
                            "classCode": "SETDHF",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635131913600.png",
                                    "name": "1635131913600",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635789",
                            "cADID": "2H12",
                            "ratedI": 100,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "161239.49,10225.0,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq1101050031df33c8d6f3a147cba2768f6e292be874",
                        "objClassCode": "SETDHF",
                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "至ETR2变压器高压开关柜（2H12）",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "c6fa88b158f349ff928d56ae6826d788",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 3140,
                            "y": 20
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "AH4",
                        "layoutIndex": 26,
                        "dataObject": {
                            "id": "Eq1101050031f75e4f0f8313472e94dd2d0af702f29f",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压馈线柜-T9PFG",
                            "localId": "2H5",
                            "localName": "至GTR1变压器高压开关柜（2H5）",
                            "objType": "equipment",
                            "classCode": "SETDHF",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635131908792.png",
                                    "name": "1635131908792",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635733",
                            "cADID": "2H5",
                            "ratedI": 100,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "158619.49,14675.0,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq1101050031f75e4f0f8313472e94dd2d0af702f29f",
                        "objClassCode": "SETDHF",
                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "至GTR1变压器高压开关柜（2H5）",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "68bbccf1c49d423c931d5bc6f35655c9",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 20,
                            "y": 20
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "AH6",
                        "layoutIndex": 0,
                        "dataObject": {
                            "id": "Eq110105003106e228756d1f46afa0020a43851abaa8",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压分段主柜-VP1B9",
                            "localId": "1H12",
                            "localName": "高压联络柜-1H12",
                            "objType": "equipment",
                            "classCode": "SETDSM",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635132479341.png",
                                    "name": "1635132479341",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635728",
                            "cADID": "1H12:高压联络柜-1H12",
                            "ratedI": 1000,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "152739.32,10225.0,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq110105003106e228756d1f46afa0020a43851abaa8",
                        "objClassCode": "SETDSM",
                        "legendId": "ecf524cf811b4817bfd4ede78887b313",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "高压联络柜-1H12",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "b49a7947e2e04b169064d5eb80421678",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 20,
                            "y": 240
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "AH6",
                        "layoutIndex": 1,
                        "dataObject": {
                            "id": "Eq11010500318d53cc4ad269457c97e9de110ee8f601",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压分段主柜-T8AJK",
                            "localId": "2H10",
                            "localName": "高压联络柜-2H10",
                            "objType": "equipment",
                            "classCode": "SETDSM",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635132475039.png",
                                    "name": "1635132475039",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635791",
                            "cADID": "2H10:高压联络柜-2H10",
                            "ratedI": 1000,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "162839.49,10225.0,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq11010500318d53cc4ad269457c97e9de110ee8f601",
                        "objClassCode": "SETDSM",
                        "legendId": "ecf524cf811b4817bfd4ede78887b313",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "高压联络柜-2H10",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "34382ce76dea492ea8f4ecc33d4df0a2",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 20,
                            "y": 460
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "AH6",
                        "layoutIndex": 2,
                        "dataObject": {
                            "id": "Eq1101050031c63be7bc95734d6ab7190c9512c94e00",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压分段主柜-BJX4D",
                            "localId": "2H11",
                            "localName": "高压联络柜-2H11",
                            "objType": "equipment",
                            "classCode": "SETDSM",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635132470795.png",
                                    "name": "1635132470795",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635792",
                            "cADID": "2H11:高压联络柜-2H11",
                            "ratedI": 1000,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "162039.49,10225.0,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq1101050031c63be7bc95734d6ab7190c9512c94e00",
                        "objClassCode": "SETDSM",
                        "legendId": "ecf524cf811b4817bfd4ede78887b313",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "高压联络柜-2H11",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "8a2c806c4ab14347b7cada41b80f32c9",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 20,
                            "y": 680
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "AH6",
                        "layoutIndex": 3,
                        "dataObject": {
                            "id": "Eq1101050031faed937fd36344919af38761f6bbcb4b",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压分段主柜-M5AQA",
                            "localId": "1H13",
                            "localName": "高压联络柜-1H13",
                            "objType": "equipment",
                            "classCode": "SETDSM",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635132466453.png",
                                    "name": "1635132466453",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635727",
                            "cADID": "1H13:高压联络柜-1H13",
                            "ratedI": 1000,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "151939.32,10225.0,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq1101050031faed937fd36344919af38761f6bbcb4b",
                        "objClassCode": "SETDSM",
                        "legendId": "ecf524cf811b4817bfd4ede78887b313",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "高压联络柜-1H13",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "90c61b8c9d9546479e281a8772d94f84",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 20,
                            "y": 20
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "BH3",
                        "layoutIndex": 0,
                        "dataObject": {
                            "id": "Eq110105003117877f1714f3412ba94d92ee8f4fcac4",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压计量柜-8EUQP",
                            "localId": "2H3",
                            "localName": "高压计量柜-2H3",
                            "objType": "equipment",
                            "classCode": "SETDHM",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635731",
                            "cADID": "2H3:计量-2H3",
                            "ratedI": 600,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "157019.49,14675.0,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq110105003117877f1714f3412ba94d92ee8f4fcac4",
                        "objClassCode": "SETDHM",
                        "legendId": "2ceb6d09e4874af998be82603f842a5f",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "高压计量柜-2H3",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "66183e7ec34b4adfa9e46cdeb8fb6a37",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 20,
                            "y": 240
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "BH3",
                        "layoutIndex": 1,
                        "dataObject": {
                            "id": "Eq11010500317084430836d04d4cb1dc46456dc54383",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压计量柜-BFR2V",
                            "localId": "2H18",
                            "localName": "高压计量柜-2H18",
                            "objType": "equipment",
                            "classCode": "SETDHM",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635797",
                            "cADID": "2H18:计量-2H18",
                            "ratedI": 600,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "156439.49,10225.0,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq11010500317084430836d04d4cb1dc46456dc54383",
                        "objClassCode": "SETDHM",
                        "legendId": "2ceb6d09e4874af998be82603f842a5f",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "高压计量柜-2H18",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "cdb25192dab14526a165f7992b0c026b",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 20,
                            "y": 460
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "BH3",
                        "layoutIndex": 2,
                        "dataObject": {
                            "id": "Eq1101050031a726021dce71421c89cd0136ccd034eb",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压计量柜-9JHDC",
                            "localId": "1H22",
                            "localName": "高压计量柜-1H22",
                            "objType": "equipment",
                            "classCode": "SETDHM",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635849",
                            "cADID": "1H22:高压计量柜-1H22",
                            "ratedI": 600,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "144764.32,10225.0,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq1101050031a726021dce71421c89cd0136ccd034eb",
                        "objClassCode": "SETDHM",
                        "legendId": "2ceb6d09e4874af998be82603f842a5f",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "高压计量柜-1H22",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "3c0d94bcf6c945a191e60eff680d2caf",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 20,
                            "y": 680
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "BH3",
                        "layoutIndex": 3,
                        "dataObject": {
                            "id": "Eq1101050031e9eec0b95e234d39a5dc40077ca9b39f",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压计量柜-JGVHX",
                            "localId": "1H3",
                            "localName": "高压计量柜-1H3",
                            "objType": "equipment",
                            "classCode": "SETDHM",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635652",
                            "cADID": "1H3:高压计量柜-1H3",
                            "ratedI": 600,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "146619.49,14675.0,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq1101050031e9eec0b95e234d39a5dc40077ca9b39f",
                        "objClassCode": "SETDHM",
                        "legendId": "2ceb6d09e4874af998be82603f842a5f",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "高压计量柜-1H3",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "dc68461bf2584b2caae7e957fd501781",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 20,
                            "y": 20
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "BH2",
                        "layoutIndex": 0,
                        "dataObject": {
                            "id": "Eq110105003106633eb7d8c44b54aa1b1e1898a90d1c",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压进线柜-AWSZJ",
                            "localId": "EH2",
                            "localName": "高压进线柜-EH2",
                            "objType": "equipment",
                            "classCode": "SETDHI",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635132319714.png",
                                    "name": "1635132319714",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB1:4426857",
                            "cADID": "EH2",
                            "ratedI": 1000,
                            "ratedU": 10,
                            "floorId": "Fl110105003188e36af7c6af4eaba983676d15ba3e66",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "121474.94,85000.01,-3950.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq110105003106633eb7d8c44b54aa1b1e1898a90d1c",
                        "objClassCode": "SETDHI",
                        "legendId": "0792d39d0ce443199d14bcd9ec3d3ff5",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "高压进线柜-EH2",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "f96074c150024d32b3770031f7c74f91",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 20,
                            "y": 240
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "BH2",
                        "layoutIndex": 1,
                        "dataObject": {
                            "id": "Eq11010500310cab8db5dfd740e79117a1e7bd25de79",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压进线柜-X7RXU",
                            "localId": "EH1",
                            "localName": "高压进线柜-EH1",
                            "objType": "equipment",
                            "classCode": "SETDHI",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635132314697.png",
                                    "name": "1635132314697",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB1:4426856",
                            "cADID": "EH1",
                            "ratedI": 1000,
                            "ratedU": 10,
                            "floorId": "Fl110105003188e36af7c6af4eaba983676d15ba3e66",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "125924.94,85000.01,-3950.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq11010500310cab8db5dfd740e79117a1e7bd25de79",
                        "objClassCode": "SETDHI",
                        "legendId": "0792d39d0ce443199d14bcd9ec3d3ff5",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "高压进线柜-EH1",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "b9d03e548b3e4166b0b10e4b73e4d450",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 20,
                            "y": 460
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "BH2",
                        "layoutIndex": 2,
                        "dataObject": {
                            "id": "Eq110105003120fbb1961a5d4cb0a05b30ad36dafc27",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压进线柜-CGBCQ",
                            "localId": "1H1",
                            "localName": "高压进线柜-1H1",
                            "objType": "equipment",
                            "classCode": "SETDHI",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635132300458.png",
                                    "name": "1635132300458",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4634495",
                            "cADID": "1H1:高压进线柜-1H1",
                            "ratedI": 1000,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "145019.49,14675.0,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq110105003120fbb1961a5d4cb0a05b30ad36dafc27",
                        "objClassCode": "SETDHI",
                        "legendId": "0792d39d0ce443199d14bcd9ec3d3ff5",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "高压进线柜-1H1",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "4b47ff646e724d26aed1ace4543596cb",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 20,
                            "y": 680
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "BH2",
                        "layoutIndex": 3,
                        "dataObject": {
                            "id": "Eq11010500312a6e15fa58cd45ab82f77d95dafb1910",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压进线柜-9W81K",
                            "localId": "2H19",
                            "localName": "高压进线柜-2H19",
                            "objType": "equipment",
                            "classCode": "SETDHI",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635132295770.png",
                                    "name": "1635132295770",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635798",
                            "cADID": "2H19:高压进线柜-2H19",
                            "ratedI": 1000,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "155639.49,10225.0,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq11010500312a6e15fa58cd45ab82f77d95dafb1910",
                        "objClassCode": "SETDHI",
                        "legendId": "0792d39d0ce443199d14bcd9ec3d3ff5",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "高压进线柜-2H19",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "4b59aae972d047a2a1895ec08623a457",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 20,
                            "y": 900
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "BH2",
                        "layoutIndex": 4,
                        "dataObject": {
                            "id": "Eq1101050031360a3ae7225341b6a6e797216e8b427b",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压进线柜-B5M7M",
                            "localId": "FH1",
                            "localName": "高压进线柜-FH1",
                            "objType": "equipment",
                            "classCode": "SETDHI",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635132291303.png",
                                    "name": "1635132291303",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:5117561",
                            "cADID": "FH1:高压进线柜-FH1",
                            "ratedI": 1000,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "202354.99,20970.46,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq1101050031360a3ae7225341b6a6e797216e8b427b",
                        "objClassCode": "SETDHI",
                        "legendId": "0792d39d0ce443199d14bcd9ec3d3ff5",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "高压进线柜-FH1",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "cb3f4e6bfe2347d09445e63ba964ec17",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 20,
                            "y": 1120
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "BH2",
                        "layoutIndex": 5,
                        "dataObject": {
                            "id": "Eq11010500313a5e92f45bb3478b893b90b0973bc863",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压进线柜-5MTRM",
                            "localId": "1H2",
                            "localName": "高压进线柜-1H2",
                            "objType": "equipment",
                            "classCode": "SETDHI",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635132253941.png",
                                    "name": "1635132253941",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635646",
                            "cADID": "1H2:高压进线柜-1H2",
                            "ratedI": 1000,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "145819.49,14675.0,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq11010500313a5e92f45bb3478b893b90b0973bc863",
                        "objClassCode": "SETDHI",
                        "legendId": "0792d39d0ce443199d14bcd9ec3d3ff5",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "高压进线柜-1H2",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "2aa95a057f9142f797feaecc192ca134",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 20,
                            "y": 1340
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "BH2",
                        "layoutIndex": 6,
                        "dataObject": {
                            "id": "Eq11010500314c8d3164c6fa470485384077d8738fc3",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压进线柜-TC521",
                            "localId": "1H23",
                            "localName": "高压进线柜-1H23",
                            "objType": "equipment",
                            "classCode": "SETDHI",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635132286764.png",
                                    "name": "1635132286764",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635855",
                            "cADID": "1H23:高压进线柜-1H23",
                            "ratedI": 1000,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "143964.32,10225.0,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq11010500314c8d3164c6fa470485384077d8738fc3",
                        "objClassCode": "SETDHI",
                        "legendId": "0792d39d0ce443199d14bcd9ec3d3ff5",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "高压进线柜-1H23",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "2dbc3d0ce0544a209bc8261eed9abd7a",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 20,
                            "y": 1560
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "BH2",
                        "layoutIndex": 7,
                        "dataObject": {
                            "id": "Eq11010500314ec806ac3b2a4fdc9cf22334bc457fb0",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压进线柜-H7JJN",
                            "localId": "HH1",
                            "localName": "高压进线柜-HH1",
                            "objType": "equipment",
                            "classCode": "SETDHI",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635132249268.png",
                                    "name": "1635132249268",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:5115971",
                            "cADID": "HH1:高压进线柜-HH1",
                            "ratedI": 1000,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "11854.99,22970.46,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq11010500314ec806ac3b2a4fdc9cf22334bc457fb0",
                        "objClassCode": "SETDHI",
                        "legendId": "0792d39d0ce443199d14bcd9ec3d3ff5",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "高压进线柜-HH1",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "5437992a7e464037b07e7903d2182325",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 20,
                            "y": 1780
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "BH2",
                        "layoutIndex": 8,
                        "dataObject": {
                            "id": "Eq11010500315022681c90c344f6b75a7794616395c8",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压进线柜-47F7S",
                            "localId": "AH2",
                            "localName": "高压进线柜-AH1B2",
                            "objType": "equipment",
                            "classCode": "SETDHI",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635132244493.png",
                                    "name": "1635132244493",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB3:4730856",
                            "cADID": "AH2",
                            "ratedI": 1000,
                            "ratedU": 10,
                            "floorId": "Fl11010500315ee406c45c4e4d46b775226827244cd2",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "102500.52,62440.88,-13050.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq11010500315022681c90c344f6b75a7794616395c8",
                        "objClassCode": "SETDHI",
                        "legendId": "0792d39d0ce443199d14bcd9ec3d3ff5",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "高压进线柜-AH1B2",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "70fa41c245ca4e1a8b12ab7bf342c4ae",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 20,
                            "y": 2000
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "BH2",
                        "layoutIndex": 9,
                        "dataObject": {
                            "id": "Eq110105003171843bb0cc4b4ff58550784064b2eb26",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压进线柜-YBZDL",
                            "localId": "1H24",
                            "localName": "高压进线柜-1H24",
                            "objType": "equipment",
                            "classCode": "SETDHI",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635132282069.png",
                                    "name": "1635132282069",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:5007513",
                            "cADID": "1H24:高压进线柜-1H24",
                            "ratedI": 1000,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "143164.32,10225.0,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq110105003171843bb0cc4b4ff58550784064b2eb26",
                        "objClassCode": "SETDHI",
                        "legendId": "0792d39d0ce443199d14bcd9ec3d3ff5",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "高压进线柜-1H24",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "d590beead9484b75b2af469795f0dbbc",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 20,
                            "y": 2220
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "BH2",
                        "layoutIndex": 10,
                        "dataObject": {
                            "id": "Eq110105003172b0ab44271d4525977da7338a3e5638",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压进线柜-LSNS5",
                            "localId": "DH2",
                            "localName": "高压进线柜-DH2",
                            "objType": "equipment",
                            "classCode": "SETDHI",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635132310116.png",
                                    "name": "1635132310116",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB1:4417594",
                            "cADID": "DH2",
                            "ratedI": 1000,
                            "ratedU": 10,
                            "floorId": "Fl110105003188e36af7c6af4eaba983676d15ba3e66",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "92175.0,85000.01,-3950.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq110105003172b0ab44271d4525977da7338a3e5638",
                        "objClassCode": "SETDHI",
                        "legendId": "0792d39d0ce443199d14bcd9ec3d3ff5",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "高压进线柜-DH2",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "3ffaa645614346e79aa57fa2839628b9",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 20,
                            "y": 2440
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "BH2",
                        "layoutIndex": 11,
                        "dataObject": {
                            "id": "Eq110105003173a0b6e5f07943d19387d0eb8d9ca940",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压进线柜-XFFVD",
                            "localId": "HH2",
                            "localName": "高压进线柜-HH2",
                            "objType": "equipment",
                            "classCode": "SETDHI",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635132277703.png",
                                    "name": "1635132277703",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:5115775",
                            "cADID": "HH2:高压进线柜-HH2",
                            "ratedI": 1000,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "11854.99,25650.47,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq110105003173a0b6e5f07943d19387d0eb8d9ca940",
                        "objClassCode": "SETDHI",
                        "legendId": "0792d39d0ce443199d14bcd9ec3d3ff5",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "高压进线柜-HH2",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "cb07e219a7734b7c8fb66cf764a1e7a3",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 20,
                            "y": 2660
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "BH2",
                        "layoutIndex": 12,
                        "dataObject": {
                            "id": "Eq11010500318b8cc19131fa4b399b83ece89e878b8d",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压进线柜-U4FW7",
                            "localId": "2H2",
                            "localName": "高压进线柜-2H2",
                            "objType": "equipment",
                            "classCode": "SETDHI",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635132273141.png",
                                    "name": "1635132273141",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635730",
                            "cADID": "2H2:高压进线柜-2H2",
                            "ratedI": 1000,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "156219.49,14675.0,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq11010500318b8cc19131fa4b399b83ece89e878b8d",
                        "objClassCode": "SETDHI",
                        "legendId": "0792d39d0ce443199d14bcd9ec3d3ff5",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "高压进线柜-2H2",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "86c11f2c2db84b97b30bca3dc94249e4",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 20,
                            "y": 2880
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "BH2",
                        "layoutIndex": 13,
                        "dataObject": {
                            "id": "Eq11010500318c798d0a9b3346609f6ad78ca9e214ff",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压进线柜-KC4YT",
                            "localId": "BH1",
                            "localName": "高压进线柜-BH1",
                            "objType": "equipment",
                            "classCode": "SETDHI",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635132239509.png",
                                    "name": "1635132239509",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB3:4730812",
                            "cADID": "BH1",
                            "ratedI": 1000,
                            "ratedU": 10,
                            "floorId": "Fl11010500315ee406c45c4e4d46b775226827244cd2",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "102500.52,66590.44,-13050.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq11010500318c798d0a9b3346609f6ad78ca9e214ff",
                        "objClassCode": "SETDHI",
                        "legendId": "0792d39d0ce443199d14bcd9ec3d3ff5",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "高压进线柜-BH1",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "8fd33aee24074b2287cfaf937257a2a4",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 20,
                            "y": 3100
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "BH2",
                        "layoutIndex": 14,
                        "dataObject": {
                            "id": "Eq11010500319d02f904f8ce404ab530faf52a0cd4e3",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压进线柜-55QZ7",
                            "localId": "BH2",
                            "localName": "高压进线柜-BH2",
                            "objType": "equipment",
                            "classCode": "SETDHI",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635132234703.png",
                                    "name": "1635132234703",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB3:4730731",
                            "cADID": "BH2",
                            "ratedI": 1000,
                            "ratedU": 10,
                            "floorId": "Fl11010500315ee406c45c4e4d46b775226827244cd2",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "102500.52,69274.44,-13050.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq11010500319d02f904f8ce404ab530faf52a0cd4e3",
                        "objClassCode": "SETDHI",
                        "legendId": "0792d39d0ce443199d14bcd9ec3d3ff5",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "高压进线柜-BH2",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "694608a529cf401495ee7cf797f01ff3",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 20,
                            "y": 3320
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "BH2",
                        "layoutIndex": 15,
                        "dataObject": {
                            "id": "Eq1101050031a169757a08784e98aa44203776863ee3",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压进线柜-B017U",
                            "localId": "FH2",
                            "localName": "高压进线柜-FH2",
                            "objType": "equipment",
                            "classCode": "SETDHI",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635132268632.png",
                                    "name": "1635132268632",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:5117560",
                            "cADID": "FH2:高压进线柜-FH2",
                            "ratedI": 1000,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "202354.99,25150.47,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq1101050031a169757a08784e98aa44203776863ee3",
                        "objClassCode": "SETDHI",
                        "legendId": "0792d39d0ce443199d14bcd9ec3d3ff5",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "高压进线柜-FH2",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "ab01f1ee3187422eb8a5e60d35939883",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 20,
                            "y": 3540
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "BH2",
                        "layoutIndex": 16,
                        "dataObject": {
                            "id": "Eq1101050031b68efd24347942a099bb293af437c833",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压进线柜-Q4PSZ",
                            "localId": "AH1",
                            "localName": "高压进线柜-AH1",
                            "objType": "equipment",
                            "classCode": "SETDHI",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635132230016.png",
                                    "name": "1635132230016",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB3:4801863",
                            "cADID": "AH1",
                            "ratedI": 1000,
                            "ratedU": 10,
                            "floorId": "Fl11010500315ee406c45c4e4d46b775226827244cd2",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "119398.08,62626.29,-13050.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq1101050031b68efd24347942a099bb293af437c833",
                        "objClassCode": "SETDHI",
                        "legendId": "0792d39d0ce443199d14bcd9ec3d3ff5",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "高压进线柜-AH1",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "15501595a6df42a08c604380d1c359c3",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 20,
                            "y": 3760
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "BH2",
                        "layoutIndex": 17,
                        "dataObject": {
                            "id": "Eq1101050031bc2a4974e0ba4b868fe3f06a75ee2ede",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压进线柜-ZHHKW",
                            "localId": "2H20",
                            "localName": "高压进线柜-2H20",
                            "objType": "equipment",
                            "classCode": "SETDHI",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635132262887.png",
                                    "name": "1635132262887",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:5007538",
                            "cADID": "2H20:高压进线柜-2H20",
                            "ratedI": 1000,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "154839.49,10225.0,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq1101050031bc2a4974e0ba4b868fe3f06a75ee2ede",
                        "objClassCode": "SETDHI",
                        "legendId": "0792d39d0ce443199d14bcd9ec3d3ff5",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "高压进线柜-2H20",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "5ddcfd43ce2d4e74bf7fce07af2fcb27",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 20,
                            "y": 3980
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "BH2",
                        "layoutIndex": 18,
                        "dataObject": {
                            "id": "Eq1101050031d9845e17932748d691ac24b5a01d4734",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压进线柜-6V6HV",
                            "localId": "2H1",
                            "localName": "高压进线柜-2H1",
                            "objType": "equipment",
                            "classCode": "SETDHI",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635132258323.png",
                                    "name": "1635132258323",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635729",
                            "cADID": "2H1:高压进线柜-2H1",
                            "ratedI": 1000,
                            "ratedU": 10,
                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "155419.49,14675.0,-8450.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq1101050031d9845e17932748d691ac24b5a01d4734",
                        "objClassCode": "SETDHI",
                        "legendId": "0792d39d0ce443199d14bcd9ec3d3ff5",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "高压进线柜-2H1",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    },
                    {
                        "id": "aad7571303b940b3b42c582ee827b9ea",
                        "name": null,
                        "compType": "equipmentNode",
                        "position": null,
                        "location": {
                            "x": 20,
                            "y": 4200
                        },
                        "size": {
                            "x": 100,
                            "y": 200
                        },
                        "hidden": false,
                        "props": null,
                        "containerId": "BH2",
                        "layoutIndex": 19,
                        "dataObject": {
                            "id": "Eq1101050031f5fa354d412c4d919168dd1561c1ea7c",
                            "valid": 1,
                            "creationTime": 1636604886000,
                            "creator": "0",
                            "projectId": "Pj1101050031",
                            "name": "高压进线柜-BVM6C",
                            "localId": "DH1",
                            "localName": "高压进线柜-DH1",
                            "objType": "equipment",
                            "classCode": "SETDHI",
                            "groupCode": "YT",
                            "grouping": 1,
                            "createApp": "datacenter",
                            "updateApp": "datacenter",
                            "pic": [
                                {
                                    "key": "1635132305189.png",
                                    "name": "1635132305189",
                                    "type": "image",
                                    "systemId": "dataPlatform",
                                    "createTime": "2021-08-12 14:05:12"
                                }
                            ],
                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB1:4426421",
                            "cADID": "DH1",
                            "ratedI": 1000,
                            "ratedU": 10,
                            "floorId": "Fl110105003188e36af7c6af4eaba983676d15ba3e66",
                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                            "bimLocation": "96625.0,85000.01,-3950.0",
                            "manufacturer": "杭州杭开电气有限公司",
                            "specification": "KYN28-12",
                            "installLocation": "高压总配电室"
                        },
                        "objId": "Eq1101050031f5fa354d412c4d919168dd1561c1ea7c",
                        "objClassCode": "SETDHI",
                        "legendId": "0792d39d0ce443199d14bcd9ec3d3ff5",
                        "label": {
                            "id": null,
                            "name": null,
                            "compType": "label",
                            "position": null,
                            "location": {
                                "x": 10,
                                "y": 10
                            },
                            "size": null,
                            "hidden": false,
                            "props": null,
                            "content": "高压进线柜-DH1",
                            "style": null
                        },
                        "anchorLocations": {
                            "B3": {
                                "x": 48,
                                "y": 200
                            },
                            "T3": {
                                "x": 48,
                                "y": 0
                            }
                        }
                    }
                ],
                "lines": [

                ],
                "template": {
                    "diagramType": "SETDHVSL",
                    "id": "cef7e4266e22489dbd78e3d8b0248292",
                    "name": "模板",
                    "code": null,
                    "remark": null,
                    "frame": {
                        "id": "frame",
                        "name": null,
                        "compType": "container",
                        "position": {
                            "minW": 200,
                            "minH": 200,
                            "paddingTop": 0,
                            "paddingRight": 0,
                            "paddingBottom": 0,
                            "paddingLeft": 0,
                            "absolute": false,
                            "absolutePoint": null
                        },
                        "location": {
                            "x": 0,
                            "y": 0
                        },
                        "size": {
                            "x": 4660,
                            "y": 4460
                        },
                        "hidden": false,
                        "props": null,
                        "children": [
                            {
                                "id": "AH1",
                                "name": "1#进线隔离及PT柜",
                                "compType": "container",
                                "position": {
                                    "minW": 100,
                                    "minH": 200,
                                    "paddingTop": 0,
                                    "paddingRight": 0,
                                    "paddingBottom": 0,
                                    "paddingLeft": 0,
                                    "absolute": false,
                                    "absolutePoint": null
                                },
                                "location": {
                                    "x": 20,
                                    "y": 20
                                },
                                "size": {
                                    "x": 100,
                                    "y": 200
                                },
                                "hidden": false,
                                "props": null,
                                "children": [

                                ],
                                "layout": {
                                    "layout": 1,
                                    "align": 0,
                                    "valign": 0,
                                    "marginTop": 20,
                                    "marginRight": 20,
                                    "marginBottom": 20,
                                    "marginLeft": 20,
                                    "spaceH": 20,
                                    "spaceV": 20
                                },
                                "equipmentTypes": [
                                    "SETDHI"
                                ],
                                "remark": null,
                                "dataFilter": {
                                    "type": 1,
                                    "not": false,
                                    "object": "name",
                                    "operation": "contains",
                                    "value": "1#;隔离"
                                },
                                "equipPack": null,
                                "dynGroup": null,
                                "groupLabel": null
                            },
                            {
                                "id": "AH2",
                                "name": "1#进线断路器柜",
                                "compType": "container",
                                "position": {
                                    "minW": 100,
                                    "minH": 200,
                                    "paddingTop": 0,
                                    "paddingRight": 0,
                                    "paddingBottom": 0,
                                    "paddingLeft": 0,
                                    "absolute": false,
                                    "absolutePoint": null
                                },
                                "location": {
                                    "x": 140,
                                    "y": 20
                                },
                                "size": {
                                    "x": 100,
                                    "y": 200
                                },
                                "hidden": false,
                                "props": null,
                                "children": [

                                ],
                                "layout": {
                                    "layout": 1,
                                    "align": 0,
                                    "valign": 0,
                                    "marginTop": 20,
                                    "marginRight": 20,
                                    "marginBottom": 20,
                                    "marginLeft": 20,
                                    "spaceH": 20,
                                    "spaceV": 20
                                },
                                "equipmentTypes": [
                                    "SETDHI"
                                ],
                                "remark": null,
                                "dataFilter": {
                                    "type": 2,
                                    "not": false,
                                    "items": [
                                        {
                                            "type": 1,
                                            "not": false,
                                            "object": "name",
                                            "operation": "contains",
                                            "value": "1#"
                                        },
                                        {
                                            "type": 1,
                                            "not": true,
                                            "object": "name",
                                            "operation": "contains",
                                            "value": "隔离"
                                        }
                                    ]
                                },
                                "equipPack": null,
                                "dynGroup": null,
                                "groupLabel": null
                            },
                            {
                                "id": "AH3",
                                "name": "1#进线计量柜",
                                "compType": "container",
                                "position": {
                                    "minW": 100,
                                    "minH": 200,
                                    "paddingTop": 0,
                                    "paddingRight": 0,
                                    "paddingBottom": 0,
                                    "paddingLeft": 0,
                                    "absolute": false,
                                    "absolutePoint": null
                                },
                                "location": {
                                    "x": 260,
                                    "y": 20
                                },
                                "size": {
                                    "x": 100,
                                    "y": 200
                                },
                                "hidden": false,
                                "props": null,
                                "children": [

                                ],
                                "layout": {
                                    "layout": 1,
                                    "align": 0,
                                    "valign": 0,
                                    "marginTop": 20,
                                    "marginRight": 20,
                                    "marginBottom": 20,
                                    "marginLeft": 20,
                                    "spaceH": 20,
                                    "spaceV": 20
                                },
                                "equipmentTypes": [
                                    "SETDHM"
                                ],
                                "remark": null,
                                "dataFilter": {
                                    "type": 1,
                                    "not": false,
                                    "object": "name",
                                    "operation": "contains",
                                    "value": "1#"
                                },
                                "equipPack": null,
                                "dynGroup": null,
                                "groupLabel": null
                            },
                            {
                                "id": "AH5",
                                "name": "1#高压送风风机断路器柜",
                                "compType": "container",
                                "position": {
                                    "minW": 100,
                                    "minH": 200,
                                    "paddingTop": 0,
                                    "paddingRight": 0,
                                    "paddingBottom": 0,
                                    "paddingLeft": 0,
                                    "absolute": false,
                                    "absolutePoint": null
                                },
                                "location": {
                                    "x": 380,
                                    "y": 20
                                },
                                "size": {
                                    "x": 140,
                                    "y": 240
                                },
                                "hidden": false,
                                "props": null,
                                "children": [
                                    {
                                        "id": "665bcb59f4354d00ab2db5528f7a0cd9",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 20,
                                            "y": 20
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "AH5",
                                        "layoutIndex": 0,
                                        "dataObject": {
                                            "id": "Eq1101050031ef68077a421c42ae9ed64d4509bc8d2f",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压馈线柜-XQ9GR",
                                            "localId": "1H4",
                                            "localName": "至1#高压冷机高压开关柜（1H4）",
                                            "objType": "equipment",
                                            "classCode": "SETDHF",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635131901077.png",
                                                    "name": "1635131901077",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635660",
                                            "cADID": "1H4",
                                            "ratedI": 100,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "147419.49,14675.0,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq1101050031ef68077a421c42ae9ed64d4509bc8d2f",
                                        "objClassCode": "SETDHF",
                                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "至1#高压冷机高压开关柜（1H4）",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    }
                                ],
                                "layout": {
                                    "layout": 2,
                                    "align": 0,
                                    "valign": 0,
                                    "marginTop": 20,
                                    "marginRight": 20,
                                    "marginBottom": 20,
                                    "marginLeft": 20,
                                    "spaceH": 20,
                                    "spaceV": 20
                                },
                                "equipmentTypes": [
                                    "SETDHF"
                                ],
                                "remark": null,
                                "dataFilter": {
                                    "type": 1,
                                    "not": false,
                                    "object": "name",
                                    "operation": "contains",
                                    "value": "1#"
                                },
                                "equipPack": null,
                                "dynGroup": null,
                                "groupLabel": null
                            },
                            {
                                "id": "AH4",
                                "name": "1#变压器断路器柜",
                                "compType": "container",
                                "position": {
                                    "minW": 100,
                                    "minH": 200,
                                    "paddingTop": 0,
                                    "paddingRight": 0,
                                    "paddingBottom": 0,
                                    "paddingLeft": 0,
                                    "absolute": false,
                                    "absolutePoint": null
                                },
                                "location": {
                                    "x": 540,
                                    "y": 20
                                },
                                "size": {
                                    "x": 3260,
                                    "y": 240
                                },
                                "hidden": false,
                                "props": null,
                                "children": [
                                    {
                                        "id": "de1b2fc7c9bb46ea820f48c01b01bdde",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 20,
                                            "y": 20
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "AH4",
                                        "layoutIndex": 0,
                                        "dataObject": {
                                            "id": "Eq110105003101228dce0fff4268aea05f1fe968eb63",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "modifiedTime": 1639034991000,
                                            "modifier": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压馈线柜-30VAS",
                                            "localId": "2H16",
                                            "localName": "至GTR2变压器高压开关柜（2H16）",
                                            "objType": "equipment",
                                            "classCode": "SETDHF",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635132039836.png",
                                                    "name": "1635132039836",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635795",
                                            "cADID": "2H16",
                                            "ratedI": 200,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "158039.49,10225.0,-8450.0",
                                            "manufacturer": "大厂",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq110105003101228dce0fff4268aea05f1fe968eb63",
                                        "objClassCode": "SETDHF",
                                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "至GTR2变压器高压开关柜（2H16）",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "104aebb297eb4fc4ad56b8401f5c62ce",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 140,
                                            "y": 20
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "AH4",
                                        "layoutIndex": 1,
                                        "dataObject": {
                                            "id": "Eq1101050031026a23aa76584336bcf695b6680f4702",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压馈线柜-MZJKK",
                                            "localId": "2H8",
                                            "localName": "至DTR1变压器高压开关柜（2H8）",
                                            "objType": "equipment",
                                            "classCode": "SETDHF",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635132033445.png",
                                                    "name": "1635132033445",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635769",
                                            "cADID": "2H8",
                                            "ratedI": 100,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "161019.49,14675.0,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq1101050031026a23aa76584336bcf695b6680f4702",
                                        "objClassCode": "SETDHF",
                                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "至DTR1变压器高压开关柜（2H8）",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "9899f9764dee43cd90b979145866f9b7",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 260,
                                            "y": 20
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "AH4",
                                        "layoutIndex": 2,
                                        "dataObject": {
                                            "id": "Eq1101050031062159cf022846e087d17615389a0e7e",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压馈线柜-L0Q0Y",
                                            "localId": "1H17",
                                            "localName": "至JTR2变压器高压开关柜（1H17）",
                                            "objType": "equipment",
                                            "classCode": "SETDHF",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635132028195.png",
                                                    "name": "1635132028195",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635806",
                                            "cADID": "1H17",
                                            "ratedI": 100,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "148739.32,10225.0,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq1101050031062159cf022846e087d17615389a0e7e",
                                        "objClassCode": "SETDHF",
                                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "至JTR2变压器高压开关柜（1H17）",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "0079b127e99c443fbde993b93a18bf58",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 380,
                                            "y": 20
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "AH4",
                                        "layoutIndex": 3,
                                        "dataObject": {
                                            "id": "Eq11010500310ef16b1a962e47f099286adf2bb266d5",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压馈线柜-SX4KP",
                                            "localId": "1H9",
                                            "localName": "至4#高压冷机高压开关柜（1H19）",
                                            "objType": "equipment",
                                            "classCode": "SETDHF",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635132021639.png",
                                                    "name": "1635132021639",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635726",
                                            "cADID": "1H9",
                                            "ratedI": 100,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "151419.49,14675.0,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq11010500310ef16b1a962e47f099286adf2bb266d5",
                                        "objClassCode": "SETDHF",
                                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "至4#高压冷机高压开关柜（1H19）",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "0c8d855d39de490a9270e8e269a7e245",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 500,
                                            "y": 20
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "AH4",
                                        "layoutIndex": 4,
                                        "dataObject": {
                                            "id": "Eq110105003128ca598367094aa191f0247062ae1cd4",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压馈线柜-Q3GG6",
                                            "localId": "2H4",
                                            "localName": "至ITR1变压器高压开关柜（2H4）",
                                            "objType": "equipment",
                                            "classCode": "SETDHF",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635132016310.png",
                                                    "name": "1635132016310",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635732",
                                            "cADID": "2H4",
                                            "ratedI": 100,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "157819.49,14675.0,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq110105003128ca598367094aa191f0247062ae1cd4",
                                        "objClassCode": "SETDHF",
                                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "至ITR1变压器高压开关柜（2H4）",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "ddad82b74c544c82afc7ec34630a5699",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 620,
                                            "y": 20
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "AH4",
                                        "layoutIndex": 5,
                                        "dataObject": {
                                            "id": "Eq110105003128e188326d0c491192e50e1dfa8f9e88",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压馈线柜-657H4",
                                            "localId": "2H14",
                                            "localName": "至DTR2变压器高压开关柜（2H14）",
                                            "objType": "equipment",
                                            "classCode": "SETDHF",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635132011691.png",
                                                    "name": "1635132011691",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635793",
                                            "cADID": "2H14",
                                            "ratedI": 100,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "159639.49,10225.0,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq110105003128e188326d0c491192e50e1dfa8f9e88",
                                        "objClassCode": "SETDHF",
                                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "至DTR2变压器高压开关柜（2H14）",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "40227bad01004fcf8b27fc9fbb5f3b6d",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 740,
                                            "y": 20
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "AH4",
                                        "layoutIndex": 6,
                                        "dataObject": {
                                            "id": "Eq1101050031313199daf1da4c0d875be48ce7abc27e",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压馈线柜-MFPK3",
                                            "localId": "1H16",
                                            "localName": "至CTR2变压器高压开关柜（1H16）",
                                            "objType": "equipment",
                                            "classCode": "SETDHF",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635132002308.png",
                                                    "name": "1635132002308",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635805",
                                            "cADID": "1H16",
                                            "ratedI": 100,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "149539.32,10225.0,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq1101050031313199daf1da4c0d875be48ce7abc27e",
                                        "objClassCode": "SETDHF",
                                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "至CTR2变压器高压开关柜（1H16）",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "fb62d9a766d74a418c1cc5379183357c",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 860,
                                            "y": 20
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "AH4",
                                        "layoutIndex": 7,
                                        "dataObject": {
                                            "id": "Eq11010500313487b5c481b94b448beff55119dfa83f",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压馈线柜-VPJ9E",
                                            "localId": "1H8",
                                            "localName": "至JTR1变压器高压开关柜（1H8）",
                                            "objType": "equipment",
                                            "classCode": "SETDHF",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635132006695.png",
                                                    "name": "1635132006695",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635709",
                                            "cADID": "1H8",
                                            "ratedI": 100,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "150619.49,14675.0,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq11010500313487b5c481b94b448beff55119dfa83f",
                                        "objClassCode": "SETDHF",
                                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "至JTR1变压器高压开关柜（1H8）",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "de98991bc9564e078c5d675698e77f28",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 980,
                                            "y": 20
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "AH4",
                                        "layoutIndex": 8,
                                        "dataObject": {
                                            "id": "Eq110105003136ea4dfb412d43ce8b7300ef5ce15ff7",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压馈线柜-U8KAC",
                                            "localId": "1H20",
                                            "localName": "至6#高压冷机高压开关柜（1H20）",
                                            "objType": "equipment",
                                            "classCode": "SETDHF",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635131997646.png",
                                                    "name": "1635131997646",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635833",
                                            "cADID": "1H20",
                                            "ratedI": 100,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "146339.32,10225.0,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq110105003136ea4dfb412d43ce8b7300ef5ce15ff7",
                                        "objClassCode": "SETDHF",
                                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "至6#高压冷机高压开关柜（1H20）",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "ee50bc4e37734870afbc4d8b947b50a1",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 1100,
                                            "y": 20
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "AH4",
                                        "layoutIndex": 9,
                                        "dataObject": {
                                            "id": "Eq110105003143051732a5ee463fa85ab9eaeeba77ff",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压馈线柜-LT3R8",
                                            "localId": "1H19",
                                            "localName": "至4#高压冷机高压开关柜（1H19）",
                                            "objType": "equipment",
                                            "classCode": "SETDHF",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635131992585.png",
                                                    "name": "1635131992585",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635808",
                                            "cADID": "1H19",
                                            "ratedI": 100,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "147139.32,10225.0,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq110105003143051732a5ee463fa85ab9eaeeba77ff",
                                        "objClassCode": "SETDHF",
                                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "至4#高压冷机高压开关柜（1H19）",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "fa9475c542b4412fb5a2c674fde0b0d7",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 1220,
                                            "y": 20
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "AH4",
                                        "layoutIndex": 10,
                                        "dataObject": {
                                            "id": "Eq1101050031501fcc3a7b52427f8cee02fcfefca03d",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压馈线柜-7XM1E",
                                            "localId": "2H13",
                                            "localName": "至GTR1变压器高压开关柜（2H5）",
                                            "objType": "equipment",
                                            "classCode": "SETDHF",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635131988003.png",
                                                    "name": "1635131988003",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635790",
                                            "cADID": "2H13",
                                            "ratedI": 100,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "160439.49,10225.0,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq1101050031501fcc3a7b52427f8cee02fcfefca03d",
                                        "objClassCode": "SETDHF",
                                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "至GTR1变压器高压开关柜（2H5）",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "46a481f457b643cfb22efa581834e180",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 1340,
                                            "y": 20
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "AH4",
                                        "layoutIndex": 11,
                                        "dataObject": {
                                            "id": "Eq110105003154c5e7447ad1427687cf0142c84fbab4",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压馈线柜-0H72G",
                                            "localId": "1H5",
                                            "localName": "至3#高压冷机高压开关柜（1H5）",
                                            "objType": "equipment",
                                            "classCode": "SETDHF",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635131983256.png",
                                                    "name": "1635131983256",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635706",
                                            "cADID": "1H5",
                                            "ratedI": 100,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "148219.49,14675.0,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq110105003154c5e7447ad1427687cf0142c84fbab4",
                                        "objClassCode": "SETDHF",
                                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "至3#高压冷机高压开关柜（1H5）",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "332e94ae0ae147f88d1b449f9ad85c6d",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 1460,
                                            "y": 20
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "AH4",
                                        "layoutIndex": 12,
                                        "dataObject": {
                                            "id": "Eq110105003156026840464d42aebb769c16ffb7f5fb",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压馈线柜-EWUJ4",
                                            "localId": "1H15",
                                            "localName": "至BTR2变压器高压开关柜（1H15）",
                                            "objType": "equipment",
                                            "classCode": "SETDHF",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635131978046.png",
                                                    "name": "1635131978046",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635804",
                                            "cADID": "1H15",
                                            "ratedI": 100,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "150339.32,10225.0,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq110105003156026840464d42aebb769c16ffb7f5fb",
                                        "objClassCode": "SETDHF",
                                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "至BTR2变压器高压开关柜（1H15）",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "c2e6557968104d47b7209c719086fd9b",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 1580,
                                            "y": 20
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "AH4",
                                        "layoutIndex": 13,
                                        "dataObject": {
                                            "id": "Eq110105003171d36433975f4c60a660451cc5b2a15a",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压馈线柜-PBMHK",
                                            "localId": "1H10",
                                            "localName": "至ATR1变压器高压开关柜（1H10）",
                                            "objType": "equipment",
                                            "classCode": "SETDHF",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635131973401.png",
                                                    "name": "1635131973401",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635802",
                                            "cADID": "1H10",
                                            "ratedI": 100,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "152219.49,14675.0,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq110105003171d36433975f4c60a660451cc5b2a15a",
                                        "objClassCode": "SETDHF",
                                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "至ATR1变压器高压开关柜（1H10）",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "7b96f2eab16d4affb441108b68afc891",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 1700,
                                            "y": 20
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "AH4",
                                        "layoutIndex": 14,
                                        "dataObject": {
                                            "id": "Eq1101050031724af298a2b8421e864583aab9db71de",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压馈线柜-1ECNN",
                                            "localId": "2H6",
                                            "localName": "至HTR1变压器高压开关柜（2H6）",
                                            "objType": "equipment",
                                            "classCode": "SETDHF",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635131968575.png",
                                                    "name": "1635131968575",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635760",
                                            "cADID": "2H6",
                                            "ratedI": 100,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "159419.49,14675.0,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq1101050031724af298a2b8421e864583aab9db71de",
                                        "objClassCode": "SETDHF",
                                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "至HTR1变压器高压开关柜（2H6）",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "4a75d62a98d1439c8b3d4ed55e610994",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 1820,
                                            "y": 20
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "AH4",
                                        "layoutIndex": 15,
                                        "dataObject": {
                                            "id": "Eq1101050031900b335312c5457bba6315e0a6a983fa",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压馈线柜-YU4GS",
                                            "localId": "1H21",
                                            "localName": "至8#高压冷机高压开关柜（1H21）",
                                            "objType": "equipment",
                                            "classCode": "SETDHF",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635131963280.png",
                                                    "name": "1635131963280",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635841",
                                            "cADID": "1H21",
                                            "ratedI": 100,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "145564.32,10225.0,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq1101050031900b335312c5457bba6315e0a6a983fa",
                                        "objClassCode": "SETDHF",
                                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "至8#高压冷机高压开关柜（1H21）",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "13d58337bc9b425283fa2433450ecf5f",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 1940,
                                            "y": 20
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "AH4",
                                        "layoutIndex": 16,
                                        "dataObject": {
                                            "id": "Eq11010500319b69d94e1d9c40e184a160453ccf0a24",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压馈线柜-3MHLZ",
                                            "localId": "1H7",
                                            "localName": "至7#高压冷机高压开关柜（1H7）",
                                            "objType": "equipment",
                                            "classCode": "SETDHF",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635131958483.png",
                                                    "name": "1635131958483",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635708",
                                            "cADID": "1H7",
                                            "ratedI": 100,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "149819.49,14675.0,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq11010500319b69d94e1d9c40e184a160453ccf0a24",
                                        "objClassCode": "SETDHF",
                                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "至7#高压冷机高压开关柜（1H7）",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "37fcd93aeef74eb3a940148769b9b692",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 2060,
                                            "y": 20
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "AH4",
                                        "layoutIndex": 17,
                                        "dataObject": {
                                            "id": "Eq11010500319e5df7eb4ba9461ea4330cb8224041de",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压馈线柜-0JRDF",
                                            "localId": "2H17",
                                            "localName": "至ITR2变压器高压开关柜（2H17）",
                                            "objType": "equipment",
                                            "classCode": "SETDHF",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635131953786.png",
                                                    "name": "1635131953786",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635796",
                                            "cADID": "2H17",
                                            "ratedI": 150,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "157239.49,10225.0,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq11010500319e5df7eb4ba9461ea4330cb8224041de",
                                        "objClassCode": "SETDHF",
                                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "至ITR2变压器高压开关柜（2H17）",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "018c985f4d094e2187fc56a276b3c567",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 2180,
                                            "y": 20
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "AH4",
                                        "layoutIndex": 18,
                                        "dataObject": {
                                            "id": "Eq1101050031a154b8ea354549a3b62eef40f03f2e15",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压馈线柜-B6NJT",
                                            "localId": "2H7",
                                            "localName": "至FTR1变压器高压开关柜（2H7）",
                                            "objType": "equipment",
                                            "classCode": "SETDHF",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635131948987.png",
                                                    "name": "1635131948987",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635761",
                                            "cADID": "2H7",
                                            "ratedI": 100,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "160219.49,14675.0,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq1101050031a154b8ea354549a3b62eef40f03f2e15",
                                        "objClassCode": "SETDHF",
                                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "至FTR1变压器高压开关柜（2H7）",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "23106fade3d14576844a1a1eac87123d",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 2300,
                                            "y": 20
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "AH4",
                                        "layoutIndex": 19,
                                        "dataObject": {
                                            "id": "Eq1101050031a366b97e21924b97bc501aed18b295af",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压馈线柜-MASE7",
                                            "localId": "2H15",
                                            "localName": "至HTR2变压器高压开关柜（2H15）",
                                            "objType": "equipment",
                                            "classCode": "SETDHF",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635131943907.png",
                                                    "name": "1635131943907",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635794",
                                            "cADID": "2H15",
                                            "ratedI": 100,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "158839.49,10225.0,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq1101050031a366b97e21924b97bc501aed18b295af",
                                        "objClassCode": "SETDHF",
                                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "至HTR2变压器高压开关柜（2H15）",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "1b08de72c361438688a4cd2c5f44a3d5",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 2420,
                                            "y": 20
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "AH4",
                                        "layoutIndex": 20,
                                        "dataObject": {
                                            "id": "Eq1101050031a9d4e7d6244e491d91ddc8f3bb52c9f8",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压馈线柜-5G0HB",
                                            "localId": "1H11",
                                            "localName": "至BTR1变压器高压开关柜（1H11）",
                                            "objType": "equipment",
                                            "classCode": "SETDHF",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635131939263.png",
                                                    "name": "1635131939263",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635801",
                                            "cADID": "1H11",
                                            "ratedI": 100,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "153019.49,14675.0,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq1101050031a9d4e7d6244e491d91ddc8f3bb52c9f8",
                                        "objClassCode": "SETDHF",
                                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "至BTR1变压器高压开关柜（1H11）",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "793cbf708aee499f8d036ea5cb3e8e52",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 2540,
                                            "y": 20
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "AH4",
                                        "layoutIndex": 21,
                                        "dataObject": {
                                            "id": "Eq1101050031aa5495ba596e4611a6b48e9eb67c5f46",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压馈线柜-F8TMX",
                                            "localId": "1H18",
                                            "localName": "至2#高压冷机高压开关柜（1H18）",
                                            "objType": "equipment",
                                            "classCode": "SETDHF",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635131934621.png",
                                                    "name": "1635131934621",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635807",
                                            "cADID": "1H18",
                                            "ratedI": 100,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "147939.32,10225.0,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq1101050031aa5495ba596e4611a6b48e9eb67c5f46",
                                        "objClassCode": "SETDHF",
                                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "至2#高压冷机高压开关柜（1H18）",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "e1515037460049d892156fb66d83548a",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 2660,
                                            "y": 20
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "AH4",
                                        "layoutIndex": 22,
                                        "dataObject": {
                                            "id": "Eq1101050031abb2871e19a74143ae43bcb68fab1c63",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压馈线柜-B9DG6",
                                            "localId": "1H14",
                                            "localName": "至ATR1变压器高压开关柜（1H14）",
                                            "objType": "equipment",
                                            "classCode": "SETDHF",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635131929119.png",
                                                    "name": "1635131929119",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635803",
                                            "cADID": "1H14",
                                            "ratedI": 100,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "151139.32,10225.0,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq1101050031abb2871e19a74143ae43bcb68fab1c63",
                                        "objClassCode": "SETDHF",
                                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "至ATR1变压器高压开关柜（1H14）",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "23c6d3b608a840ecad4e0a741a4d0021",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 2780,
                                            "y": 20
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "AH4",
                                        "layoutIndex": 23,
                                        "dataObject": {
                                            "id": "Eq1101050031c8665c4ca53d4b36b6d87b1542e7a732",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压馈线柜-NP9T5",
                                            "localId": "1H6",
                                            "localName": "至5#高压冷机高压开关柜（1H6）",
                                            "objType": "equipment",
                                            "classCode": "SETDHF",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635131923416.png",
                                                    "name": "1635131923416",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635707",
                                            "cADID": "1H6",
                                            "ratedI": 100,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "149019.49,14675.0,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq1101050031c8665c4ca53d4b36b6d87b1542e7a732",
                                        "objClassCode": "SETDHF",
                                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "至5#高压冷机高压开关柜（1H6）",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "79e0a727d71f4691b9584a32499c0af0",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 2900,
                                            "y": 20
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "AH4",
                                        "layoutIndex": 24,
                                        "dataObject": {
                                            "id": "Eq1101050031de22c8e4b6c94c998b23ec8ffbf5cbf9",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压馈线柜-VJKJP",
                                            "localId": "2H9",
                                            "localName": "至ETR1变压器高压开关柜（2H9）",
                                            "objType": "equipment",
                                            "classCode": "SETDHF",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635131918643.png",
                                                    "name": "1635131918643",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635770",
                                            "cADID": "2H9",
                                            "ratedI": 150,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "161819.49,14675.0,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq1101050031de22c8e4b6c94c998b23ec8ffbf5cbf9",
                                        "objClassCode": "SETDHF",
                                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "至ETR1变压器高压开关柜（2H9）",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "bd5b097b4bb8402a976c18e536c2de28",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 3020,
                                            "y": 20
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "AH4",
                                        "layoutIndex": 25,
                                        "dataObject": {
                                            "id": "Eq1101050031df33c8d6f3a147cba2768f6e292be874",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压馈线柜-TVQF3",
                                            "localId": "2H12",
                                            "localName": "至ETR2变压器高压开关柜（2H12）",
                                            "objType": "equipment",
                                            "classCode": "SETDHF",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635131913600.png",
                                                    "name": "1635131913600",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635789",
                                            "cADID": "2H12",
                                            "ratedI": 100,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "161239.49,10225.0,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq1101050031df33c8d6f3a147cba2768f6e292be874",
                                        "objClassCode": "SETDHF",
                                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "至ETR2变压器高压开关柜（2H12）",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "c6fa88b158f349ff928d56ae6826d788",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 3140,
                                            "y": 20
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "AH4",
                                        "layoutIndex": 26,
                                        "dataObject": {
                                            "id": "Eq1101050031f75e4f0f8313472e94dd2d0af702f29f",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压馈线柜-T9PFG",
                                            "localId": "2H5",
                                            "localName": "至GTR1变压器高压开关柜（2H5）",
                                            "objType": "equipment",
                                            "classCode": "SETDHF",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635131908792.png",
                                                    "name": "1635131908792",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635733",
                                            "cADID": "2H5",
                                            "ratedI": 100,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "158619.49,14675.0,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq1101050031f75e4f0f8313472e94dd2d0af702f29f",
                                        "objClassCode": "SETDHF",
                                        "legendId": "2de2ea60811f44d6b7063db6550608e2",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "至GTR1变压器高压开关柜（2H5）",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    }
                                ],
                                "layout": {
                                    "layout": 2,
                                    "align": 0,
                                    "valign": 0,
                                    "marginTop": 20,
                                    "marginRight": 20,
                                    "marginBottom": 20,
                                    "marginLeft": 20,
                                    "spaceH": 20,
                                    "spaceV": 20
                                },
                                "equipmentTypes": [
                                    "SETDHF"
                                ],
                                "remark": null,
                                "dataFilter": null,
                                "equipPack": null,
                                "dynGroup": null,
                                "groupLabel": null
                            },
                            {
                                "id": "AH6",
                                "name": "1#母线高压联络股",
                                "compType": "container",
                                "position": {
                                    "minW": 100,
                                    "minH": 200,
                                    "paddingTop": 0,
                                    "paddingRight": 0,
                                    "paddingBottom": 0,
                                    "paddingLeft": 0,
                                    "absolute": false,
                                    "absolutePoint": null
                                },
                                "location": {
                                    "x": 3820,
                                    "y": 20
                                },
                                "size": {
                                    "x": 140,
                                    "y": 900
                                },
                                "hidden": false,
                                "props": null,
                                "children": [
                                    {
                                        "id": "68bbccf1c49d423c931d5bc6f35655c9",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 20,
                                            "y": 20
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "AH6",
                                        "layoutIndex": 0,
                                        "dataObject": {
                                            "id": "Eq110105003106e228756d1f46afa0020a43851abaa8",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压分段主柜-VP1B9",
                                            "localId": "1H12",
                                            "localName": "高压联络柜-1H12",
                                            "objType": "equipment",
                                            "classCode": "SETDSM",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635132479341.png",
                                                    "name": "1635132479341",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635728",
                                            "cADID": "1H12:高压联络柜-1H12",
                                            "ratedI": 1000,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "152739.32,10225.0,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq110105003106e228756d1f46afa0020a43851abaa8",
                                        "objClassCode": "SETDSM",
                                        "legendId": "ecf524cf811b4817bfd4ede78887b313",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "高压联络柜-1H12",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "b49a7947e2e04b169064d5eb80421678",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 20,
                                            "y": 240
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "AH6",
                                        "layoutIndex": 1,
                                        "dataObject": {
                                            "id": "Eq11010500318d53cc4ad269457c97e9de110ee8f601",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压分段主柜-T8AJK",
                                            "localId": "2H10",
                                            "localName": "高压联络柜-2H10",
                                            "objType": "equipment",
                                            "classCode": "SETDSM",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635132475039.png",
                                                    "name": "1635132475039",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635791",
                                            "cADID": "2H10:高压联络柜-2H10",
                                            "ratedI": 1000,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "162839.49,10225.0,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq11010500318d53cc4ad269457c97e9de110ee8f601",
                                        "objClassCode": "SETDSM",
                                        "legendId": "ecf524cf811b4817bfd4ede78887b313",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "高压联络柜-2H10",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "34382ce76dea492ea8f4ecc33d4df0a2",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 20,
                                            "y": 460
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "AH6",
                                        "layoutIndex": 2,
                                        "dataObject": {
                                            "id": "Eq1101050031c63be7bc95734d6ab7190c9512c94e00",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压分段主柜-BJX4D",
                                            "localId": "2H11",
                                            "localName": "高压联络柜-2H11",
                                            "objType": "equipment",
                                            "classCode": "SETDSM",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635132470795.png",
                                                    "name": "1635132470795",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635792",
                                            "cADID": "2H11:高压联络柜-2H11",
                                            "ratedI": 1000,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "162039.49,10225.0,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq1101050031c63be7bc95734d6ab7190c9512c94e00",
                                        "objClassCode": "SETDSM",
                                        "legendId": "ecf524cf811b4817bfd4ede78887b313",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "高压联络柜-2H11",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "8a2c806c4ab14347b7cada41b80f32c9",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 20,
                                            "y": 680
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "AH6",
                                        "layoutIndex": 3,
                                        "dataObject": {
                                            "id": "Eq1101050031faed937fd36344919af38761f6bbcb4b",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压分段主柜-M5AQA",
                                            "localId": "1H13",
                                            "localName": "高压联络柜-1H13",
                                            "objType": "equipment",
                                            "classCode": "SETDSM",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635132466453.png",
                                                    "name": "1635132466453",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635727",
                                            "cADID": "1H13:高压联络柜-1H13",
                                            "ratedI": 1000,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "151939.32,10225.0,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq1101050031faed937fd36344919af38761f6bbcb4b",
                                        "objClassCode": "SETDSM",
                                        "legendId": "ecf524cf811b4817bfd4ede78887b313",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "高压联络柜-1H13",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    }
                                ],
                                "layout": {
                                    "layout": 1,
                                    "align": 0,
                                    "valign": 0,
                                    "marginTop": 20,
                                    "marginRight": 20,
                                    "marginBottom": 20,
                                    "marginLeft": 20,
                                    "spaceH": 20,
                                    "spaceV": 20
                                },
                                "equipmentTypes": [
                                    "SETDSM"
                                ],
                                "remark": null,
                                "dataFilter": null,
                                "equipPack": null,
                                "dynGroup": null,
                                "groupLabel": null
                            },
                            {
                                "id": "BH5",
                                "name": "2#高压送风风机断路器柜",
                                "compType": "container",
                                "position": {
                                    "minW": 100,
                                    "minH": 200,
                                    "paddingTop": 0,
                                    "paddingRight": 0,
                                    "paddingBottom": 0,
                                    "paddingLeft": 0,
                                    "absolute": false,
                                    "absolutePoint": null
                                },
                                "location": {
                                    "x": 3980,
                                    "y": 20
                                },
                                "size": {
                                    "x": 100,
                                    "y": 200
                                },
                                "hidden": false,
                                "props": null,
                                "children": [

                                ],
                                "layout": {
                                    "layout": 2,
                                    "align": 0,
                                    "valign": 0,
                                    "marginTop": 20,
                                    "marginRight": 20,
                                    "marginBottom": 20,
                                    "marginLeft": 20,
                                    "spaceH": 20,
                                    "spaceV": 20
                                },
                                "equipmentTypes": [
                                    "SETDHF"
                                ],
                                "remark": null,
                                "dataFilter": null,
                                "equipPack": null,
                                "dynGroup": null,
                                "groupLabel": null
                            },
                            {
                                "id": "BH4",
                                "name": "2#变压器断路器柜",
                                "compType": "container",
                                "position": {
                                    "minW": 100,
                                    "minH": 200,
                                    "paddingTop": 0,
                                    "paddingRight": 0,
                                    "paddingBottom": 0,
                                    "paddingLeft": 0,
                                    "absolute": false,
                                    "absolutePoint": null
                                },
                                "location": {
                                    "x": 4100,
                                    "y": 20
                                },
                                "size": {
                                    "x": 100,
                                    "y": 200
                                },
                                "hidden": false,
                                "props": null,
                                "children": [

                                ],
                                "layout": {
                                    "layout": 2,
                                    "align": 0,
                                    "valign": 0,
                                    "marginTop": 20,
                                    "marginRight": 20,
                                    "marginBottom": 20,
                                    "marginLeft": 20,
                                    "spaceH": 20,
                                    "spaceV": 20
                                },
                                "equipmentTypes": [
                                    "SETDHF"
                                ],
                                "remark": null,
                                "dataFilter": null,
                                "equipPack": null,
                                "dynGroup": null,
                                "groupLabel": null
                            },
                            {
                                "id": "BH3",
                                "name": "2#高压计量柜",
                                "compType": "container",
                                "position": {
                                    "minW": 100,
                                    "minH": 200,
                                    "paddingTop": 0,
                                    "paddingRight": 0,
                                    "paddingBottom": 0,
                                    "paddingLeft": 0,
                                    "absolute": false,
                                    "absolutePoint": null
                                },
                                "location": {
                                    "x": 4220,
                                    "y": 20
                                },
                                "size": {
                                    "x": 140,
                                    "y": 900
                                },
                                "hidden": false,
                                "props": null,
                                "children": [
                                    {
                                        "id": "90c61b8c9d9546479e281a8772d94f84",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 20,
                                            "y": 20
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "BH3",
                                        "layoutIndex": 0,
                                        "dataObject": {
                                            "id": "Eq110105003117877f1714f3412ba94d92ee8f4fcac4",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压计量柜-8EUQP",
                                            "localId": "2H3",
                                            "localName": "高压计量柜-2H3",
                                            "objType": "equipment",
                                            "classCode": "SETDHM",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635731",
                                            "cADID": "2H3:计量-2H3",
                                            "ratedI": 600,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "157019.49,14675.0,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq110105003117877f1714f3412ba94d92ee8f4fcac4",
                                        "objClassCode": "SETDHM",
                                        "legendId": "2ceb6d09e4874af998be82603f842a5f",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "高压计量柜-2H3",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "66183e7ec34b4adfa9e46cdeb8fb6a37",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 20,
                                            "y": 240
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "BH3",
                                        "layoutIndex": 1,
                                        "dataObject": {
                                            "id": "Eq11010500317084430836d04d4cb1dc46456dc54383",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压计量柜-BFR2V",
                                            "localId": "2H18",
                                            "localName": "高压计量柜-2H18",
                                            "objType": "equipment",
                                            "classCode": "SETDHM",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635797",
                                            "cADID": "2H18:计量-2H18",
                                            "ratedI": 600,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "156439.49,10225.0,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq11010500317084430836d04d4cb1dc46456dc54383",
                                        "objClassCode": "SETDHM",
                                        "legendId": "2ceb6d09e4874af998be82603f842a5f",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "高压计量柜-2H18",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "cdb25192dab14526a165f7992b0c026b",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 20,
                                            "y": 460
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "BH3",
                                        "layoutIndex": 2,
                                        "dataObject": {
                                            "id": "Eq1101050031a726021dce71421c89cd0136ccd034eb",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压计量柜-9JHDC",
                                            "localId": "1H22",
                                            "localName": "高压计量柜-1H22",
                                            "objType": "equipment",
                                            "classCode": "SETDHM",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635849",
                                            "cADID": "1H22:高压计量柜-1H22",
                                            "ratedI": 600,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "144764.32,10225.0,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq1101050031a726021dce71421c89cd0136ccd034eb",
                                        "objClassCode": "SETDHM",
                                        "legendId": "2ceb6d09e4874af998be82603f842a5f",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "高压计量柜-1H22",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "3c0d94bcf6c945a191e60eff680d2caf",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 20,
                                            "y": 680
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "BH3",
                                        "layoutIndex": 3,
                                        "dataObject": {
                                            "id": "Eq1101050031e9eec0b95e234d39a5dc40077ca9b39f",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压计量柜-JGVHX",
                                            "localId": "1H3",
                                            "localName": "高压计量柜-1H3",
                                            "objType": "equipment",
                                            "classCode": "SETDHM",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635652",
                                            "cADID": "1H3:高压计量柜-1H3",
                                            "ratedI": 600,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "146619.49,14675.0,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq1101050031e9eec0b95e234d39a5dc40077ca9b39f",
                                        "objClassCode": "SETDHM",
                                        "legendId": "2ceb6d09e4874af998be82603f842a5f",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "高压计量柜-1H3",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    }
                                ],
                                "layout": {
                                    "layout": 1,
                                    "align": 0,
                                    "valign": 0,
                                    "marginTop": 20,
                                    "marginRight": 20,
                                    "marginBottom": 20,
                                    "marginLeft": 20,
                                    "spaceH": 20,
                                    "spaceV": 20
                                },
                                "equipmentTypes": [
                                    "SETDHM"
                                ],
                                "remark": null,
                                "dataFilter": null,
                                "equipPack": null,
                                "dynGroup": null,
                                "groupLabel": null
                            },
                            {
                                "id": "BH2",
                                "name": "2#高压进线断路器柜",
                                "compType": "container",
                                "position": {
                                    "minW": 100,
                                    "minH": 200,
                                    "paddingTop": 0,
                                    "paddingRight": 0,
                                    "paddingBottom": 0,
                                    "paddingLeft": 0,
                                    "absolute": false,
                                    "absolutePoint": null
                                },
                                "location": {
                                    "x": 4380,
                                    "y": 20
                                },
                                "size": {
                                    "x": 140,
                                    "y": 4420
                                },
                                "hidden": false,
                                "props": null,
                                "children": [
                                    {
                                        "id": "dc68461bf2584b2caae7e957fd501781",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 20,
                                            "y": 20
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "BH2",
                                        "layoutIndex": 0,
                                        "dataObject": {
                                            "id": "Eq110105003106633eb7d8c44b54aa1b1e1898a90d1c",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压进线柜-AWSZJ",
                                            "localId": "EH2",
                                            "localName": "高压进线柜-EH2",
                                            "objType": "equipment",
                                            "classCode": "SETDHI",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635132319714.png",
                                                    "name": "1635132319714",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB1:4426857",
                                            "cADID": "EH2",
                                            "ratedI": 1000,
                                            "ratedU": 10,
                                            "floorId": "Fl110105003188e36af7c6af4eaba983676d15ba3e66",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "121474.94,85000.01,-3950.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq110105003106633eb7d8c44b54aa1b1e1898a90d1c",
                                        "objClassCode": "SETDHI",
                                        "legendId": "0792d39d0ce443199d14bcd9ec3d3ff5",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "高压进线柜-EH2",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "f96074c150024d32b3770031f7c74f91",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 20,
                                            "y": 240
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "BH2",
                                        "layoutIndex": 1,
                                        "dataObject": {
                                            "id": "Eq11010500310cab8db5dfd740e79117a1e7bd25de79",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压进线柜-X7RXU",
                                            "localId": "EH1",
                                            "localName": "高压进线柜-EH1",
                                            "objType": "equipment",
                                            "classCode": "SETDHI",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635132314697.png",
                                                    "name": "1635132314697",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB1:4426856",
                                            "cADID": "EH1",
                                            "ratedI": 1000,
                                            "ratedU": 10,
                                            "floorId": "Fl110105003188e36af7c6af4eaba983676d15ba3e66",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "125924.94,85000.01,-3950.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq11010500310cab8db5dfd740e79117a1e7bd25de79",
                                        "objClassCode": "SETDHI",
                                        "legendId": "0792d39d0ce443199d14bcd9ec3d3ff5",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "高压进线柜-EH1",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "b9d03e548b3e4166b0b10e4b73e4d450",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 20,
                                            "y": 460
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "BH2",
                                        "layoutIndex": 2,
                                        "dataObject": {
                                            "id": "Eq110105003120fbb1961a5d4cb0a05b30ad36dafc27",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压进线柜-CGBCQ",
                                            "localId": "1H1",
                                            "localName": "高压进线柜-1H1",
                                            "objType": "equipment",
                                            "classCode": "SETDHI",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635132300458.png",
                                                    "name": "1635132300458",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4634495",
                                            "cADID": "1H1:高压进线柜-1H1",
                                            "ratedI": 1000,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "145019.49,14675.0,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq110105003120fbb1961a5d4cb0a05b30ad36dafc27",
                                        "objClassCode": "SETDHI",
                                        "legendId": "0792d39d0ce443199d14bcd9ec3d3ff5",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "高压进线柜-1H1",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "4b47ff646e724d26aed1ace4543596cb",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 20,
                                            "y": 680
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "BH2",
                                        "layoutIndex": 3,
                                        "dataObject": {
                                            "id": "Eq11010500312a6e15fa58cd45ab82f77d95dafb1910",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压进线柜-9W81K",
                                            "localId": "2H19",
                                            "localName": "高压进线柜-2H19",
                                            "objType": "equipment",
                                            "classCode": "SETDHI",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635132295770.png",
                                                    "name": "1635132295770",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635798",
                                            "cADID": "2H19:高压进线柜-2H19",
                                            "ratedI": 1000,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "155639.49,10225.0,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq11010500312a6e15fa58cd45ab82f77d95dafb1910",
                                        "objClassCode": "SETDHI",
                                        "legendId": "0792d39d0ce443199d14bcd9ec3d3ff5",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "高压进线柜-2H19",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "4b59aae972d047a2a1895ec08623a457",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 20,
                                            "y": 900
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "BH2",
                                        "layoutIndex": 4,
                                        "dataObject": {
                                            "id": "Eq1101050031360a3ae7225341b6a6e797216e8b427b",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压进线柜-B5M7M",
                                            "localId": "FH1",
                                            "localName": "高压进线柜-FH1",
                                            "objType": "equipment",
                                            "classCode": "SETDHI",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635132291303.png",
                                                    "name": "1635132291303",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:5117561",
                                            "cADID": "FH1:高压进线柜-FH1",
                                            "ratedI": 1000,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "202354.99,20970.46,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq1101050031360a3ae7225341b6a6e797216e8b427b",
                                        "objClassCode": "SETDHI",
                                        "legendId": "0792d39d0ce443199d14bcd9ec3d3ff5",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "高压进线柜-FH1",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "cb3f4e6bfe2347d09445e63ba964ec17",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 20,
                                            "y": 1120
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "BH2",
                                        "layoutIndex": 5,
                                        "dataObject": {
                                            "id": "Eq11010500313a5e92f45bb3478b893b90b0973bc863",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压进线柜-5MTRM",
                                            "localId": "1H2",
                                            "localName": "高压进线柜-1H2",
                                            "objType": "equipment",
                                            "classCode": "SETDHI",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635132253941.png",
                                                    "name": "1635132253941",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635646",
                                            "cADID": "1H2:高压进线柜-1H2",
                                            "ratedI": 1000,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "145819.49,14675.0,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq11010500313a5e92f45bb3478b893b90b0973bc863",
                                        "objClassCode": "SETDHI",
                                        "legendId": "0792d39d0ce443199d14bcd9ec3d3ff5",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "高压进线柜-1H2",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "2aa95a057f9142f797feaecc192ca134",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 20,
                                            "y": 1340
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "BH2",
                                        "layoutIndex": 6,
                                        "dataObject": {
                                            "id": "Eq11010500314c8d3164c6fa470485384077d8738fc3",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压进线柜-TC521",
                                            "localId": "1H23",
                                            "localName": "高压进线柜-1H23",
                                            "objType": "equipment",
                                            "classCode": "SETDHI",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635132286764.png",
                                                    "name": "1635132286764",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635855",
                                            "cADID": "1H23:高压进线柜-1H23",
                                            "ratedI": 1000,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "143964.32,10225.0,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq11010500314c8d3164c6fa470485384077d8738fc3",
                                        "objClassCode": "SETDHI",
                                        "legendId": "0792d39d0ce443199d14bcd9ec3d3ff5",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "高压进线柜-1H23",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "2dbc3d0ce0544a209bc8261eed9abd7a",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 20,
                                            "y": 1560
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "BH2",
                                        "layoutIndex": 7,
                                        "dataObject": {
                                            "id": "Eq11010500314ec806ac3b2a4fdc9cf22334bc457fb0",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压进线柜-H7JJN",
                                            "localId": "HH1",
                                            "localName": "高压进线柜-HH1",
                                            "objType": "equipment",
                                            "classCode": "SETDHI",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635132249268.png",
                                                    "name": "1635132249268",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:5115971",
                                            "cADID": "HH1:高压进线柜-HH1",
                                            "ratedI": 1000,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "11854.99,22970.46,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq11010500314ec806ac3b2a4fdc9cf22334bc457fb0",
                                        "objClassCode": "SETDHI",
                                        "legendId": "0792d39d0ce443199d14bcd9ec3d3ff5",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "高压进线柜-HH1",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "5437992a7e464037b07e7903d2182325",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 20,
                                            "y": 1780
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "BH2",
                                        "layoutIndex": 8,
                                        "dataObject": {
                                            "id": "Eq11010500315022681c90c344f6b75a7794616395c8",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压进线柜-47F7S",
                                            "localId": "AH2",
                                            "localName": "高压进线柜-AH1B2",
                                            "objType": "equipment",
                                            "classCode": "SETDHI",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635132244493.png",
                                                    "name": "1635132244493",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB3:4730856",
                                            "cADID": "AH2",
                                            "ratedI": 1000,
                                            "ratedU": 10,
                                            "floorId": "Fl11010500315ee406c45c4e4d46b775226827244cd2",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "102500.52,62440.88,-13050.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq11010500315022681c90c344f6b75a7794616395c8",
                                        "objClassCode": "SETDHI",
                                        "legendId": "0792d39d0ce443199d14bcd9ec3d3ff5",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "高压进线柜-AH1B2",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "70fa41c245ca4e1a8b12ab7bf342c4ae",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 20,
                                            "y": 2000
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "BH2",
                                        "layoutIndex": 9,
                                        "dataObject": {
                                            "id": "Eq110105003171843bb0cc4b4ff58550784064b2eb26",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压进线柜-YBZDL",
                                            "localId": "1H24",
                                            "localName": "高压进线柜-1H24",
                                            "objType": "equipment",
                                            "classCode": "SETDHI",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635132282069.png",
                                                    "name": "1635132282069",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:5007513",
                                            "cADID": "1H24:高压进线柜-1H24",
                                            "ratedI": 1000,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "143164.32,10225.0,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq110105003171843bb0cc4b4ff58550784064b2eb26",
                                        "objClassCode": "SETDHI",
                                        "legendId": "0792d39d0ce443199d14bcd9ec3d3ff5",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "高压进线柜-1H24",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "d590beead9484b75b2af469795f0dbbc",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 20,
                                            "y": 2220
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "BH2",
                                        "layoutIndex": 10,
                                        "dataObject": {
                                            "id": "Eq110105003172b0ab44271d4525977da7338a3e5638",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压进线柜-LSNS5",
                                            "localId": "DH2",
                                            "localName": "高压进线柜-DH2",
                                            "objType": "equipment",
                                            "classCode": "SETDHI",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635132310116.png",
                                                    "name": "1635132310116",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB1:4417594",
                                            "cADID": "DH2",
                                            "ratedI": 1000,
                                            "ratedU": 10,
                                            "floorId": "Fl110105003188e36af7c6af4eaba983676d15ba3e66",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "92175.0,85000.01,-3950.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq110105003172b0ab44271d4525977da7338a3e5638",
                                        "objClassCode": "SETDHI",
                                        "legendId": "0792d39d0ce443199d14bcd9ec3d3ff5",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "高压进线柜-DH2",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "3ffaa645614346e79aa57fa2839628b9",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 20,
                                            "y": 2440
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "BH2",
                                        "layoutIndex": 11,
                                        "dataObject": {
                                            "id": "Eq110105003173a0b6e5f07943d19387d0eb8d9ca940",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压进线柜-XFFVD",
                                            "localId": "HH2",
                                            "localName": "高压进线柜-HH2",
                                            "objType": "equipment",
                                            "classCode": "SETDHI",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635132277703.png",
                                                    "name": "1635132277703",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:5115775",
                                            "cADID": "HH2:高压进线柜-HH2",
                                            "ratedI": 1000,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "11854.99,25650.47,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq110105003173a0b6e5f07943d19387d0eb8d9ca940",
                                        "objClassCode": "SETDHI",
                                        "legendId": "0792d39d0ce443199d14bcd9ec3d3ff5",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "高压进线柜-HH2",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "cb07e219a7734b7c8fb66cf764a1e7a3",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 20,
                                            "y": 2660
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "BH2",
                                        "layoutIndex": 12,
                                        "dataObject": {
                                            "id": "Eq11010500318b8cc19131fa4b399b83ece89e878b8d",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压进线柜-U4FW7",
                                            "localId": "2H2",
                                            "localName": "高压进线柜-2H2",
                                            "objType": "equipment",
                                            "classCode": "SETDHI",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635132273141.png",
                                                    "name": "1635132273141",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635730",
                                            "cADID": "2H2:高压进线柜-2H2",
                                            "ratedI": 1000,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "156219.49,14675.0,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq11010500318b8cc19131fa4b399b83ece89e878b8d",
                                        "objClassCode": "SETDHI",
                                        "legendId": "0792d39d0ce443199d14bcd9ec3d3ff5",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "高压进线柜-2H2",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "86c11f2c2db84b97b30bca3dc94249e4",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 20,
                                            "y": 2880
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "BH2",
                                        "layoutIndex": 13,
                                        "dataObject": {
                                            "id": "Eq11010500318c798d0a9b3346609f6ad78ca9e214ff",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压进线柜-KC4YT",
                                            "localId": "BH1",
                                            "localName": "高压进线柜-BH1",
                                            "objType": "equipment",
                                            "classCode": "SETDHI",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635132239509.png",
                                                    "name": "1635132239509",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB3:4730812",
                                            "cADID": "BH1",
                                            "ratedI": 1000,
                                            "ratedU": 10,
                                            "floorId": "Fl11010500315ee406c45c4e4d46b775226827244cd2",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "102500.52,66590.44,-13050.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq11010500318c798d0a9b3346609f6ad78ca9e214ff",
                                        "objClassCode": "SETDHI",
                                        "legendId": "0792d39d0ce443199d14bcd9ec3d3ff5",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "高压进线柜-BH1",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "8fd33aee24074b2287cfaf937257a2a4",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 20,
                                            "y": 3100
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "BH2",
                                        "layoutIndex": 14,
                                        "dataObject": {
                                            "id": "Eq11010500319d02f904f8ce404ab530faf52a0cd4e3",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压进线柜-55QZ7",
                                            "localId": "BH2",
                                            "localName": "高压进线柜-BH2",
                                            "objType": "equipment",
                                            "classCode": "SETDHI",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635132234703.png",
                                                    "name": "1635132234703",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB3:4730731",
                                            "cADID": "BH2",
                                            "ratedI": 1000,
                                            "ratedU": 10,
                                            "floorId": "Fl11010500315ee406c45c4e4d46b775226827244cd2",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "102500.52,69274.44,-13050.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq11010500319d02f904f8ce404ab530faf52a0cd4e3",
                                        "objClassCode": "SETDHI",
                                        "legendId": "0792d39d0ce443199d14bcd9ec3d3ff5",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "高压进线柜-BH2",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "694608a529cf401495ee7cf797f01ff3",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 20,
                                            "y": 3320
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "BH2",
                                        "layoutIndex": 15,
                                        "dataObject": {
                                            "id": "Eq1101050031a169757a08784e98aa44203776863ee3",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压进线柜-B017U",
                                            "localId": "FH2",
                                            "localName": "高压进线柜-FH2",
                                            "objType": "equipment",
                                            "classCode": "SETDHI",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635132268632.png",
                                                    "name": "1635132268632",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:5117560",
                                            "cADID": "FH2:高压进线柜-FH2",
                                            "ratedI": 1000,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "202354.99,25150.47,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq1101050031a169757a08784e98aa44203776863ee3",
                                        "objClassCode": "SETDHI",
                                        "legendId": "0792d39d0ce443199d14bcd9ec3d3ff5",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "高压进线柜-FH2",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "ab01f1ee3187422eb8a5e60d35939883",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 20,
                                            "y": 3540
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "BH2",
                                        "layoutIndex": 16,
                                        "dataObject": {
                                            "id": "Eq1101050031b68efd24347942a099bb293af437c833",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压进线柜-Q4PSZ",
                                            "localId": "AH1",
                                            "localName": "高压进线柜-AH1",
                                            "objType": "equipment",
                                            "classCode": "SETDHI",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635132230016.png",
                                                    "name": "1635132230016",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB3:4801863",
                                            "cADID": "AH1",
                                            "ratedI": 1000,
                                            "ratedU": 10,
                                            "floorId": "Fl11010500315ee406c45c4e4d46b775226827244cd2",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "119398.08,62626.29,-13050.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq1101050031b68efd24347942a099bb293af437c833",
                                        "objClassCode": "SETDHI",
                                        "legendId": "0792d39d0ce443199d14bcd9ec3d3ff5",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "高压进线柜-AH1",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "15501595a6df42a08c604380d1c359c3",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 20,
                                            "y": 3760
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "BH2",
                                        "layoutIndex": 17,
                                        "dataObject": {
                                            "id": "Eq1101050031bc2a4974e0ba4b868fe3f06a75ee2ede",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压进线柜-ZHHKW",
                                            "localId": "2H20",
                                            "localName": "高压进线柜-2H20",
                                            "objType": "equipment",
                                            "classCode": "SETDHI",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635132262887.png",
                                                    "name": "1635132262887",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:5007538",
                                            "cADID": "2H20:高压进线柜-2H20",
                                            "ratedI": 1000,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "154839.49,10225.0,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq1101050031bc2a4974e0ba4b868fe3f06a75ee2ede",
                                        "objClassCode": "SETDHI",
                                        "legendId": "0792d39d0ce443199d14bcd9ec3d3ff5",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "高压进线柜-2H20",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "5ddcfd43ce2d4e74bf7fce07af2fcb27",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 20,
                                            "y": 3980
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "BH2",
                                        "layoutIndex": 18,
                                        "dataObject": {
                                            "id": "Eq1101050031d9845e17932748d691ac24b5a01d4734",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压进线柜-6V6HV",
                                            "localId": "2H1",
                                            "localName": "高压进线柜-2H1",
                                            "objType": "equipment",
                                            "classCode": "SETDHI",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635132258323.png",
                                                    "name": "1635132258323",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB2:4635729",
                                            "cADID": "2H1:高压进线柜-2H1",
                                            "ratedI": 1000,
                                            "ratedU": 10,
                                            "floorId": "Fl1101050031e763f95cad5748cd9a62665904282543",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "155419.49,14675.0,-8450.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq1101050031d9845e17932748d691ac24b5a01d4734",
                                        "objClassCode": "SETDHI",
                                        "legendId": "0792d39d0ce443199d14bcd9ec3d3ff5",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "高压进线柜-2H1",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    },
                                    {
                                        "id": "aad7571303b940b3b42c582ee827b9ea",
                                        "name": null,
                                        "compType": "equipmentNode",
                                        "position": null,
                                        "location": {
                                            "x": 20,
                                            "y": 4200
                                        },
                                        "size": {
                                            "x": 100,
                                            "y": 200
                                        },
                                        "hidden": false,
                                        "props": null,
                                        "containerId": "BH2",
                                        "layoutIndex": 19,
                                        "dataObject": {
                                            "id": "Eq1101050031f5fa354d412c4d919168dd1561c1ea7c",
                                            "valid": 1,
                                            "creationTime": 1636604886000,
                                            "creator": "0",
                                            "projectId": "Pj1101050031",
                                            "name": "高压进线柜-BVM6C",
                                            "localId": "DH1",
                                            "localName": "高压进线柜-DH1",
                                            "objType": "equipment",
                                            "classCode": "SETDHI",
                                            "groupCode": "YT",
                                            "grouping": 1,
                                            "createApp": "datacenter",
                                            "updateApp": "datacenter",
                                            "pic": [
                                                {
                                                    "key": "1635132305189.png",
                                                    "name": "1635132305189",
                                                    "type": "image",
                                                    "systemId": "dataPlatform",
                                                    "createTime": "2021-08-12 14:05:12"
                                                }
                                            ],
                                            "bimId": "Pj110105003154bde233e08311ebad193735987ad77eB1:4426421",
                                            "cADID": "DH1",
                                            "ratedI": 1000,
                                            "ratedU": 10,
                                            "floorId": "Fl110105003188e36af7c6af4eaba983676d15ba3e66",
                                            "buildingId": "Bd1101050031055f11181e4b40efb7ca6f684d685216",
                                            "bimLocation": "96625.0,85000.01,-3950.0",
                                            "manufacturer": "杭州杭开电气有限公司",
                                            "specification": "KYN28-12",
                                            "installLocation": "高压总配电室"
                                        },
                                        "objId": "Eq1101050031f5fa354d412c4d919168dd1561c1ea7c",
                                        "objClassCode": "SETDHI",
                                        "legendId": "0792d39d0ce443199d14bcd9ec3d3ff5",
                                        "label": {
                                            "id": null,
                                            "name": null,
                                            "compType": "label",
                                            "position": null,
                                            "location": {
                                                "x": 10,
                                                "y": 10
                                            },
                                            "size": null,
                                            "hidden": false,
                                            "props": null,
                                            "content": "高压进线柜-DH1",
                                            "style": null
                                        },
                                        "anchorLocations": {
                                            "B3": {
                                                "x": 48,
                                                "y": 200
                                            },
                                            "T3": {
                                                "x": 48,
                                                "y": 0
                                            }
                                        }
                                    }
                                ],
                                "layout": {
                                    "layout": 1,
                                    "align": 0,
                                    "valign": 0,
                                    "marginTop": 20,
                                    "marginRight": 20,
                                    "marginBottom": 20,
                                    "marginLeft": 20,
                                    "spaceH": 20,
                                    "spaceV": 20
                                },
                                "equipmentTypes": [
                                    "SETDHI"
                                ],
                                "remark": null,
                                "dataFilter": null,
                                "equipPack": null,
                                "dynGroup": null,
                                "groupLabel": null
                            },
                            {
                                "id": "BH1",
                                "name": "2#进线隔离及PT柜",
                                "compType": "container",
                                "position": {
                                    "minW": 100,
                                    "minH": 200,
                                    "paddingTop": 0,
                                    "paddingRight": 0,
                                    "paddingBottom": 0,
                                    "paddingLeft": 0,
                                    "absolute": false,
                                    "absolutePoint": null
                                },
                                "location": {
                                    "x": 4540,
                                    "y": 20
                                },
                                "size": {
                                    "x": 100,
                                    "y": 200
                                },
                                "hidden": false,
                                "props": null,
                                "children": [

                                ],
                                "layout": {
                                    "layout": 1,
                                    "align": 0,
                                    "valign": 0,
                                    "marginTop": 20,
                                    "marginRight": 20,
                                    "marginBottom": 20,
                                    "marginLeft": 20,
                                    "spaceH": 20,
                                    "spaceV": 20
                                },
                                "equipmentTypes": [
                                    "SETDHI"
                                ],
                                "remark": null,
                                "dataFilter": null,
                                "equipPack": null,
                                "dynGroup": null,
                                "groupLabel": null
                            }
                        ],
                        "layout": {
                            "layout": 2,
                            "align": 0,
                            "valign": 0,
                            "marginTop": 20,
                            "marginRight": 20,
                            "marginBottom": 20,
                            "marginLeft": 20,
                            "spaceH": 20,
                            "spaceV": 20
                        },
                        "equipmentTypes": null,
                        "remark": null,
                        "dataFilter": null,
                        "equipPack": null,
                        "dynGroup": null,
                        "groupLabel": null
                    },
                    "scatteredContainers": null,
                    "mainPipes": [
                        {
                            "id": "362a40b011b143e7aa2b31d075523f37",
                            "name": "1#高压供电母线",
                            "lineStyle": null,
                            "label": null,
                            "dataObject": null,
                            "dataObjectId": null,
                            "remark": null,
                            "pipeType": null,
                            "passbyRels": [
                                "HUDistribution/Normal"
                            ],
                            "connectEquips": [
                                "SETDHF",
                                "SETDHP",
                                "SETDSM",
                                "SETDSA"
                            ],
                            "equipmentTypes": [
                                "SETDBB"
                            ],
                            "bindEquipment": true,
                            "dataFilter": null,
                            "path": [
                                [
                                    {
                                        "containerId": "AH3",
                                        "refPointName": "tl",
                                        "offset": {
                                            "x": 0,
                                            "y": -9
                                        }
                                    },
                                    {
                                        "containerId": "AH6",
                                        "refPointName": "tr",
                                        "offset": {
                                            "x": 0,
                                            "y": -9
                                        }
                                    }
                                ]
                            ],
                            "locationPath": [
                                [
                                    {
                                        "x": 260,
                                        "y": 11
                                    },
                                    {
                                        "x": 3960,
                                        "y": 11
                                    }
                                ]
                            ]
                        },
                        {
                            "id": "a14767ed0e81444e8b5d683b92acb86c",
                            "name": "1#高压进线母线",
                            "lineStyle": null,
                            "label": null,
                            "dataObject": null,
                            "dataObjectId": null,
                            "remark": null,
                            "pipeType": null,
                            "passbyRels": [
                                "HUDistribution/Normal"
                            ],
                            "connectEquips": [
                                "SETDHI"
                            ],
                            "equipmentTypes": [
                                "SETDBB"
                            ],
                            "bindEquipment": true,
                            "dataFilter": null,
                            "path": [
                                [
                                    {
                                        "containerId": "AH1",
                                        "refPointName": "tl",
                                        "offset": {
                                            "x": 0,
                                            "y": -7
                                        }
                                    },
                                    {
                                        "containerId": "AH2",
                                        "refPointName": "tr",
                                        "offset": {
                                            "x": -1,
                                            "y": -7
                                        }
                                    }
                                ]
                            ],
                            "locationPath": [
                                [
                                    {
                                        "x": 20,
                                        "y": 13
                                    },
                                    {
                                        "x": 239,
                                        "y": 13
                                    }
                                ]
                            ]
                        },
                        {
                            "id": "7c34073fa7e04009a4b483712f92ac04",
                            "name": "2#高压进线母线",
                            "lineStyle": null,
                            "label": null,
                            "dataObject": null,
                            "dataObjectId": null,
                            "remark": null,
                            "pipeType": null,
                            "passbyRels": [
                                "HUDistribution/Normal"
                            ],
                            "connectEquips": [
                                "SETDHI"
                            ],
                            "equipmentTypes": [
                                "SETDBB"
                            ],
                            "bindEquipment": false,
                            "dataFilter": null,
                            "path": [
                                [
                                    {
                                        "containerId": "BH1",
                                        "refPointName": "tr",
                                        "offset": {
                                            "x": 0,
                                            "y": -8
                                        }
                                    },
                                    {
                                        "containerId": "BH2",
                                        "refPointName": "tl",
                                        "offset": {
                                            "x": -3,
                                            "y": -8
                                        }
                                    }
                                ]
                            ],
                            "locationPath": [
                                [
                                    {
                                        "x": 4640,
                                        "y": 12
                                    },
                                    {
                                        "x": 4377,
                                        "y": 12
                                    }
                                ]
                            ]
                        },
                        {
                            "id": "b72761db04c94ee795457edbcfd744d4",
                            "name": null,
                            "lineStyle": null,
                            "label": null,
                            "dataObject": null,
                            "dataObjectId": null,
                            "remark": null,
                            "pipeType": null,
                            "passbyRels": null,
                            "connectEquips": null,
                            "equipmentTypes": null,
                            "bindEquipment": false,
                            "dataFilter": null,
                            "path": [
                                [
                                    {
                                        "containerId": "BH2",
                                        "refPointName": "B2",
                                        "offset": {
                                            "x": -1,
                                            "y": 0
                                        }
                                    },
                                    {
                                        "containerId": "BH2",
                                        "refPointName": "B2",
                                        "offset": {
                                            "x": -1,
                                            "y": 14
                                        }
                                    },
                                    {
                                        "containerId": "BH3",
                                        "refPointName": "B3",
                                        "offset": {
                                            "x": 12,
                                            "y": 14
                                        }
                                    },
                                    {
                                        "containerId": "BH3",
                                        "refPointName": "T3",
                                        "offset": {
                                            "x": 12,
                                            "y": -6
                                        }
                                    }
                                ]
                            ],
                            "locationPath": [
                                [
                                    {
                                        "x": 4449,
                                        "y": 4440
                                    },
                                    {
                                        "x": 4449,
                                        "y": 4454
                                    },
                                    {
                                        "x": 4337,
                                        "y": 934
                                    },
                                    {
                                        "x": 4337,
                                        "y": 14
                                    }
                                ]
                            ]
                        },
                        {
                            "id": "7cef04d672d24d9e93cf774067828654",
                            "name": "2#高压供电母线",
                            "lineStyle": null,
                            "label": null,
                            "dataObject": null,
                            "dataObjectId": null,
                            "remark": null,
                            "pipeType": null,
                            "passbyRels": [
                                "HUDistribution/Normal"
                            ],
                            "connectEquips": [
                                "SETDHF",
                                "SETDHP",
                                "SETDHM",
                                "SETDSA",
                                "SETDSM"
                            ],
                            "equipmentTypes": [
                                "SETDBB"
                            ],
                            "bindEquipment": false,
                            "dataFilter": null,
                            "path": [
                                [
                                    {
                                        "containerId": "BH3",
                                        "refPointName": "tr",
                                        "offset": {
                                            "x": 1,
                                            "y": -7
                                        }
                                    },
                                    {
                                        "containerId": "BH5",
                                        "refPointName": "tl",
                                        "offset": {
                                            "x": 0,
                                            "y": -7
                                        }
                                    }
                                ]
                            ],
                            "locationPath": [
                                [
                                    {
                                        "x": 4361,
                                        "y": 13
                                    },
                                    {
                                        "x": 3980,
                                        "y": 13
                                    }
                                ]
                            ]
                        },
                        {
                            "id": "fe797a12aefb44e4b72e65dcb60c997f",
                            "name": "1#高压联络母线",
                            "lineStyle": null,
                            "label": null,
                            "dataObject": null,
                            "dataObjectId": null,
                            "remark": "这根母线是由互备连接关系引出的，两边连接的一个是高压分段主柜，另一端连接的是另外一个柜子里面的母线。高压分段辅柜现在很少出现了",
                            "pipeType": null,
                            "passbyRels": [
                                "HUDistribution/Backup"
                            ],
                            "connectEquips": [
                                "SETDSA",
                                "SETDSM"
                            ],
                            "equipmentTypes": [
                                "SETDBB"
                            ],
                            "bindEquipment": false,
                            "dataFilter": null,
                            "path": [
                                [
                                    {
                                        "containerId": "AH6",
                                        "refPointName": "B2",
                                        "offset": {
                                            "x": 0,
                                            "y": 3
                                        }
                                    },
                                    {
                                        "containerId": "AH6",
                                        "refPointName": "B2",
                                        "offset": {
                                            "x": 0,
                                            "y": 14
                                        }
                                    },
                                    {
                                        "containerId": "AH6",
                                        "refPointName": "br",
                                        "offset": {
                                            "x": 10,
                                            "y": 14
                                        }
                                    },
                                    {
                                        "containerId": "AH6",
                                        "refPointName": "tr",
                                        "offset": {
                                            "x": 10,
                                            "y": -12
                                        }
                                    },
                                    {
                                        "containerId": "BH4",
                                        "refPointName": "T1",
                                        "offset": {
                                            "x": 9,
                                            "y": -12
                                        }
                                    },
                                    {
                                        "containerId": "BH4",
                                        "refPointName": "T1",
                                        "offset": {
                                            "x": 9,
                                            "y": -7
                                        }
                                    }
                                ]
                            ],
                            "locationPath": [
                                [
                                    {
                                        "x": 3890,
                                        "y": 923
                                    },
                                    {
                                        "x": 3890,
                                        "y": 934
                                    },
                                    {
                                        "x": 3970,
                                        "y": 934
                                    },
                                    {
                                        "x": 3970,
                                        "y": 8
                                    },
                                    {
                                        "x": 4134,
                                        "y": 8
                                    },
                                    {
                                        "x": 4134,
                                        "y": 13
                                    }
                                ]
                            ]
                        },
                        {
                            "id": "74926f917a754d129f2f166114f0e0c7",
                            "name": null,
                            "lineStyle": null,
                            "label": null,
                            "dataObject": null,
                            "dataObjectId": null,
                            "remark": null,
                            "pipeType": null,
                            "passbyRels": null,
                            "connectEquips": null,
                            "equipmentTypes": null,
                            "bindEquipment": false,
                            "dataFilter": null,
                            "path": [
                                [
                                    {
                                        "containerId": "AH5",
                                        "refPointName": "B2",
                                        "offset": {
                                            "x": -1,
                                            "y": -2
                                        }
                                    },
                                    {
                                        "containerId": "AH5",
                                        "refPointName": "B2",
                                        "offset": {
                                            "x": -1,
                                            "y": 52
                                        }
                                    }
                                ]
                            ],
                            "locationPath": [
                                [
                                    {
                                        "x": 449,
                                        "y": 258
                                    },
                                    {
                                        "x": 449,
                                        "y": 312
                                    }
                                ]
                            ]
                        },
                        {
                            "id": "91a9a5486f574689ae1b41092a016353",
                            "name": null,
                            "lineStyle": null,
                            "label": null,
                            "dataObject": null,
                            "dataObjectId": null,
                            "remark": null,
                            "pipeType": null,
                            "passbyRels": null,
                            "connectEquips": null,
                            "equipmentTypes": null,
                            "bindEquipment": false,
                            "dataFilter": null,
                            "path": [
                                [
                                    {
                                        "containerId": "AH4",
                                        "refPointName": "B2",
                                        "offset": {
                                            "x": 0,
                                            "y": 1
                                        }
                                    },
                                    {
                                        "containerId": "AH4",
                                        "refPointName": "B2",
                                        "offset": {
                                            "x": 0,
                                            "y": 52
                                        }
                                    }
                                ]
                            ],
                            "locationPath": [
                                [
                                    {
                                        "x": 2170,
                                        "y": 261
                                    },
                                    {
                                        "x": 2170,
                                        "y": 312
                                    }
                                ]
                            ]
                        }
                    ]
                }
            }
        };
    }


    /**
    * 更新系统图状态
    * @param _paramObj  {id:'系统图ID',state:'系统图状态'}
    */
    static async updateSysGraphState(_paramObj: any) {
        var url = '/diagram/update/state';
        var resultObj = await this.sysGraphHttpUtilsInstance.postRequest(url, _paramObj);
        return resultObj;
    }

    /**
    * 删除系统图
    * @param id 系统图ID
    */
    static async delSysGraph(id: string) {
        var resultObj = await this.updateSysGraphState({ id: id, state: graphStateEnum.Recyle });
        return resultObj;
    }

    /**
    * 上架系统图
    * @param id 系统图ID
    */
    static async publishSysGraph(id: string) {
        var resultObj = await this.updateSysGraphState({ id: id, state: graphStateEnum.Publish });
        return resultObj;
    }

    /**
    * 下架系统图
    * @param id 系统图ID
    */
    static async draftGraph(id: string) {
        var resultObj = await this.updateSysGraphState({ id: id, state: graphStateEnum.Draft });
        return resultObj;
    }

    /**
     * 打开系统图新增、预览、编辑页面
     * @param state 打开新页面时的状态，0 预览； 1 编辑；  2 新建
     * @param diagramId 系统图ID
     * @param groupCode 集团编码
     * @param projectId 项目ID
     * @param projectName 项目名称
     * @param baseUrl 根路径
     * @param isOpenTarget 是否打开新页面
     */
    static openGraphPage(state: number, diagramId: string, groupCode: string, projectId: string, projectName: string, baseUrl: string, isOpenTarget: boolean) {
        var url = "/" +
            baseUrl +
            logicConfig.routerNameConfig.systemGraphEditName +
            "?ost=" +
            state +
            "&did=" +
            (diagramId || "") +
            '&gc=' + (groupCode || '') +
            '&pri=' + (projectId || '') +
            '&prn=' + encodeURIComponent(projectName || '');
        isOpenTarget === true ? window.open(url) : window.location.href = url;
    }

}